<?php
// add_finance.php
session_start();
require_once '../config.php';

if (!isset($_SESSION['user'])) {
    header("Location: ../login.php");
    exit;
}

$conn = get_db_connection();
$conn->set_charset("utf8mb4");

$success = '';
$error = '';
$batch_add = isset($_GET['batch_add']) && $_GET['batch_add'] === '1';

// 提交处理
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $record_type = $_POST['record_type'] ?? '';
    $category = $_POST['category'] ?? '';
    $amount = floatval($_POST['amount'] ?? 0);
    $payment_method = $_POST['payment_method'] ?? '';
    $description = $_POST['description'] ?? '';
    $created_by = $_SESSION['user']['id'];

    $created_at = $_POST['created_at'] ?? '';
    if (empty($created_at)) {
        $created_at = date('Y-m-d H:i:s');
    } else {
        $created_at = str_replace('T', ' ', $created_at);
    }

    $batch_add = isset($_POST['batch_add']) && $_POST['batch_add'] == '1';

    if ($record_type && $category && $amount > 0 && $payment_method) {
        $stmt = $conn->prepare("INSERT INTO financial_records (record_type, category, amount, payment_method, description, created_at, created_by) VALUES (?, ?, ?, ?, ?, ?, ?)");
        $stmt->bind_param("ssdsssi", $record_type, $category, $amount, $payment_method, $description, $created_at, $created_by);

        if ($stmt->execute()) {
            if ($batch_add) {
                header("Location: add_finance.php?batch_add=1&success=1");
                exit;
            } else {
                header("Location: list_finance.php?message=" . urlencode("✅ 添加成功"));
                exit;
            }
        } else {
            $error = "❌ 数据库错误: " . $stmt->error;
        }
        $stmt->close();
    } else {
        $error = "❌ 请填写完整内容";
    }
}
?>
<!DOCTYPE html>
<html lang="zh">

<head>
    <meta charset="UTF-8">
    <title>添加财务记录</title>
    <link rel="stylesheet" href="style.css">
</head>

<body>
    <div class="header">
        <h2>添加财务记录</h2>
        <a href="list_finance.php" class="btn btn-secondary">返回列表</a>
    </div>

    <div class="container">
        <?php if (isset($_GET['success'])): ?>
            <div class="message">✅ 添加成功</div>
        <?php elseif ($error): ?>
            <div class="message" style="background-color: #f8d7da; color: #721c24;"><?= $error ?></div>
        <?php endif; ?>

        <form method="post">
            <div class="form-row">
                <div class="form-col">
                    <label>类型:</label>
                    <select name="record_type" required>
                        <option value="">请选择</option>
                        <option value="收入">收入</option>
                        <option value="支出">支出</option>
                    </select>
                </div>
                <div class="form-col">
                    <label>分类:</label>
                    <input type="text" name="category" required placeholder="如 批发销售 / 冷链运输">
                </div>
            </div>

            <div class="form-row">
                <div class="form-col">
                    <label>金额(元):</label>
                    <input type="number" step="0.01" name="amount" required>
                </div>
                <div class="form-col">
                    <label>支付方式:</label>
                    <select name="payment_method" required>
                        <option value="">请选择</option>
                        <option value="现金">现金</option>
                        <option value="微信">微信</option>
                        <option value="支付宝">支付宝</option>
                        <option value="银行卡">银行卡</option>
                        <option value="转账">转账</option>
                        <option value="其他">其他</option>
                    </select>
                </div>
            </div>

            <div class="form-group">
                <label>说明:</label>
                <textarea name="description" placeholder="可选，如客户信息、货品等"></textarea>
            </div>

            <div class="form-group">
                <label>记录时间:</label>
                <input type="datetime-local" name="created_at">
            </div>

            <div class="btn-group">
                <label style="margin-right: 10px;">
                    <input type="checkbox" name="batch_add" value="1" <?= $batch_add ? 'checked' : '' ?>> 批量添加
                </label>
                <button type="submit" class="btn">保存</button>
                <button type="reset" class="btn btn-secondary">重置</button>
            </div>
        </form>
    </div>
</body>

</html>