<?php
// report.php - 财务报表
require_once '../config.php';
$conn = get_db_connection();
$conn->set_charset("utf8mb4");

// 获取当前日期
$today = date('Y-m-d');
$thisMonth = date('Y-m');
$thisYear = date('Y');

// 获取报表类型（日/月/年），默认日报
$type = $_GET['type'] ?? 'day';

// 设置默认日期筛选值
if (!isset($_GET['date']) || $_GET['date'] === '') {
    $dateFilter = $type === 'month' ? $thisMonth : ($type === 'year' ? $thisYear : $today);
} else {
    $dateFilter = $_GET['date'];
}

// SQL 日期格式与 input 类型
switch ($type) {
    case 'month':
        $groupFormat = '%Y-%m-%d';  // 按天统计
        $label = '日期';
        $inputType = 'month';
        break;
    case 'year':
        $groupFormat = '%Y-%m';     // 按月统计
        $label = '月份';
        $inputType = 'number';
        break;
    default:
        $groupFormat = '%Y-%m-%d';
        $label = '日期';
        $inputType = 'date';
        $type = 'day';
        break;
}

// 获取所有年份（用于 year 报表）
$yearOptions = [];
if ($type === 'year') {
    $yearResult = $conn->query("SELECT DISTINCT YEAR(created_at) as y FROM financial_records ORDER BY y DESC");
    while ($yRow = $yearResult->fetch_assoc()) {
        $yearOptions[] = $yRow['y'];
    }
}

// 构造时间范围并补空数据
$labels = [];
$dataMap = [];

if ($type === 'month' && preg_match('/^\d{4}-\d{2}$/', $dateFilter)) {
    $daysInMonth = date('t', strtotime($dateFilter . '-01'));
    for ($d = 1; $d <= $daysInMonth; $d++) {
        $day = sprintf('%s-%02d', $dateFilter, $d);
        $labels[] = $day;
        $dataMap[$day] = ['income' => 0, 'expense' => 0];
    }
    $where = "WHERE DATE_FORMAT(created_at, '%Y-%m') = '$dateFilter'";
} elseif ($type === 'year' && preg_match('/^\d{4}$/', $dateFilter)) {
    for ($m = 1; $m <= 12; $m++) {
        $month = sprintf('%s-%02d', $dateFilter, $m);
        $labels[] = $month;
        $dataMap[$month] = ['income' => 0, 'expense' => 0];
    }
    $where = "WHERE YEAR(created_at) = '$dateFilter'";
} elseif ($type === 'day' && preg_match('/^\d{4}-\d{2}-\d{2}$/', $dateFilter)) {
    $labels[] = $dateFilter;
    $dataMap[$dateFilter] = ['income' => 0, 'expense' => 0];
    $where = "WHERE DATE(created_at) = '$dateFilter'";
} else {
    $where = '';
}

// 查询数据
$sql = "
    SELECT 
        DATE_FORMAT(created_at, '$groupFormat') as period,
        SUM(CASE WHEN record_type='收入' THEN amount ELSE 0 END) AS income_total,
        SUM(CASE WHEN record_type='支出' THEN amount ELSE 0 END) AS expense_total
    FROM financial_records
    $where
    GROUP BY period
    ORDER BY period ASC
";

$result = $conn->query($sql);
if ($result && $result->num_rows > 0) {
    while ($row = $result->fetch_assoc()) {
        $period = $row['period'];
        if (isset($dataMap[$period])) {
            $dataMap[$period]['income'] = floatval($row['income_total']);
            $dataMap[$period]['expense'] = floatval($row['expense_total']);
        }
    }
}

$incomeData = array_column($dataMap, 'income');
$expenseData = array_column($dataMap, 'expense');
?>
<!DOCTYPE html>
<html lang="zh">

<head>
    <meta charset="UTF-8">
    <title>财务报表</title>
    <link rel="stylesheet" href="style.css">
    <script src="https://cdn.jsdelivr.net/npm/chart.js@3.9.1/dist/chart.min.js"></script>

</head>

<body>
    <div class="header">
        <h2>财务报表</h2>
        <div class="button-group">
            <a href="?type=day" class="btn <?= $type === 'day' ? 'btn-add' : '' ?>">日报表</a>
            <a href="?type=month" class="btn <?= $type === 'month' ? 'btn-add' : '' ?>">月报表</a>
            <a href="?type=year" class="btn <?= $type === 'year' ? 'btn-add' : '' ?>">年报表</a>
        </div>
    </div>

    <div class="container">
        <form method="get" class="search-box" style="margin-bottom: 20px; gap: 10px;">
            <input type="hidden" name="type" value="<?= $type ?>">
            <label>选择<?= $label ?>:</label>
            <?php if ($type === 'year'): ?>
                <select name="date">
                    <option value="">全部年份</option>
                    <?php foreach ($yearOptions as $y): ?>
                        <option value="<?= $y ?>" <?= $dateFilter == $y ? 'selected' : '' ?>><?= $y ?></option>
                    <?php endforeach; ?>
                </select>
            <?php else: ?>
                <input type="<?= $inputType ?>" name="date" value="<?= htmlspecialchars($dateFilter) ?>">
            <?php endif; ?>
            <button type="submit" class="btn">筛选</button>
        </form>

        <div class="button-group" style="margin-bottom: 15px;">
            <button class="btn" onclick="showChart('bar')">柱状图</button>
            <button class="btn" onclick="showChart('line')">折线图</button>
        </div>

        <div class="container" style="margin-bottom: 25px;">
            <canvas id="financeChart" height="100"></canvas>
        </div>

        <div class="table-container">
            <table>
                <thead>
                    <tr>
                        <th width="160"><?= $label ?></th>
                        <th>总收入(元)</th>
                        <th>总支出(元)</th>
                        <th>净收益(元)</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($labels as $i => $period): ?>
                        <tr>
                            <td><?= $period ?></td>
                            <td style="color:green;">+<?= number_format($incomeData[$i], 2) ?></td>
                            <td style="color:red;">-<?= number_format($expenseData[$i], 2) ?></td>
                            <td>
                                <?php
                                $net = $incomeData[$i] - $expenseData[$i];
                                echo ($net >= 0 ? '✅ ' : '❌ ') . number_format($net, 2);
                                ?>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
                <tfoot>
                    <?php if ($type === 'month' || $type === 'year'): ?>
                        <?php
                        $totalIncome = array_sum($incomeData);
                        $totalExpense = array_sum($expenseData);
                        $netProfit = $totalIncome - $totalExpense;
                        ?>
                        <tr style="font-weight: bold; background-color: #f5f5f5;">
                            <td>合计</td>
                            <td style="color:green;">+<?= number_format($totalIncome, 2) ?></td>
                            <td style="color:red;">-<?= number_format($totalExpense, 2) ?></td>
                            <td><?= ($netProfit >= 0 ? '✅ ' : '❌ ') . number_format($netProfit, 2) ?></td>
                        </tr>
                    <?php endif; ?>
                </tfoot>

            </table>
        </div>
    </div>

    <script>
        let chart;

        function showChart(type) {
            const ctx = document.getElementById('financeChart').getContext('2d');
            if (chart) chart.destroy();
            chart = new Chart(ctx, {
                type: type,
                data: {
                    labels: <?= json_encode($labels) ?>,
                    datasets: [{
                            label: '总收入(元)',
                            data: <?= json_encode($incomeData) ?>,
                            backgroundColor: 'rgba(75, 192, 192, 0.5)',
                            borderColor: 'rgba(75, 192, 192, 1)',
                            borderWidth: 2,
                            fill: false
                        },
                        {
                            label: '总支出(元)',
                            data: <?= json_encode($expenseData) ?>,
                            backgroundColor: 'rgba(255, 99, 132, 0.5)',
                            borderColor: 'rgba(255, 99, 132, 1)',
                            borderWidth: 2,
                            fill: false
                        }
                    ]
                },
                options: {
                    responsive: true,
                    plugins: {
                        legend: {
                            position: 'top'
                        },
                        title: {
                            display: true,
                            text: '财务<?= $label ?>统计图'
                        }
                    }
                }
            });
        }

        // 默认显示柱状图
        window.onload = function() {
            showChart('bar');
        };
    </script>
</body>

</html>