<?php
// list_records.php - 财务记录列表
require_once '../config.php';
$conn = get_db_connection();
$conn->set_charset("utf8mb4");

$message = $_GET['message'] ?? '';

// 搜索条件
$search = $_GET['search'] ?? '';
$where = '';
if (!empty($search)) {
    $search = $conn->real_escape_string($search);
    $where = "WHERE category LIKE '%$search%' OR description LIKE '%$search%'";
}

// 分页设置
$page = max(1, intval($_GET['page'] ?? 1));
$limit = 10;
$offset = ($page - 1) * $limit;

// 获取总数
$totalResult = $conn->query("SELECT COUNT(*) as total FROM financial_records $where");
$totalRows = $totalResult->fetch_assoc()['total'] ?? 0;
$totalPages = ceil($totalRows / $limit);

// 查询数据
$sql = "
    SELECT r.*, u.real_name 
    FROM financial_records r
    LEFT JOIN users u ON r.created_by = u.id
    $where
    ORDER BY r.created_at DESC
    LIMIT $offset, $limit
";

$result = $conn->query($sql);

// 格式化日期，去掉时分秒
function formatDate($datetime)
{
    return date('Y-m-d', strtotime($datetime));
}
?>
<!DOCTYPE html>
<html lang="zh">

<head>
    <meta charset="UTF-8">
    <title>财务记录列表</title>
    <link rel="stylesheet" href="style.css">
</head>

<body>
    <div class="header">
        <h2>财务记录列表</h2>
        <div class="button-group">
            <a href="add_finance.php" class="btn btn-add">添加记录</a>
        </div>
    </div>
    <?php if ($message): ?>
        <div class="message"><?= htmlspecialchars($message) ?></div>
    <?php endif; ?>
    <form method="get" class="search-box">
        <input type="text" name="search" placeholder="搜索分类/说明" value="<?= htmlspecialchars($search) ?>">
        <button type="submit">搜索</button>
    </form>

    <div class="table-container">
        <table>
            <thead>
                <tr>
                    <th width="90">类型</th>
                    <th width="130">分类</th>
                    <th width="90">金额(元)</th>
                    <th width="90">支付方式</th>
                    <th>说明</th>
                    <th width="100">录入人</th>
                    <th width="90">时间</th>
                    <th width="60">操作</th>
                </tr>
            </thead>
            <tbody>
                <?php if ($result && $result->num_rows > 0): ?>
                    <?php while ($row = $result->fetch_assoc()): ?>
                        <tr>
                            <td><?= $row['record_type'] === '收入' ? '🟢 收入' : '🔴 支出' ?></td>
                            <td><?= htmlspecialchars($row['category']) ?></td>
                            <td><?= number_format($row['amount'], 2) ?></td>
                            <td><?= htmlspecialchars($row['payment_method']) ?></td>
                            <td class="description"><?= htmlspecialchars($row['description']) ?></td>
                            <td><?= htmlspecialchars($row['real_name'] ?? '—') ?></td>
                            <td><?= formatDate($row['created_at']) ?></td>
                            <td><a href="edit_finance.php?id=<?= $row['id'] ?>" class="btn">编辑</a></td>
                        </tr>
                    <?php endwhile; ?>
                <?php else: ?>
                    <tr>
                        <td colspan="8" style="text-align:center; padding: 20px;">暂无记录</td>
                    </tr>
                <?php endif; ?>
            </tbody>
        </table>
    </div>

    <?php if ($totalPages > 1): ?>
        <div class="pagination">
            <?php if ($page > 1): ?>
                <a href="?page=1&search=<?= urlencode($search) ?>">首页</a>
                <a href="?page=<?= $page - 1 ?>&search=<?= urlencode($search) ?>">上一页</a>
            <?php endif; ?>

            <?php for ($i = max(1, $page - 2); $i <= min($totalPages, $page + 2); $i++): ?>
                <?php if ($i === $page): ?>
                    <span class="current"><?= $i ?></span>
                <?php else: ?>
                    <a href="?page=<?= $i ?>&search=<?= urlencode($search) ?>"><?= $i ?></a>
                <?php endif; ?>
            <?php endfor; ?>

            <?php if ($page < $totalPages): ?>
                <a href="?page=<?= $page + 1 ?>&search=<?= urlencode($search) ?>">下一页</a>
                <a href="?page=<?= $totalPages ?>&search=<?= urlencode($search) ?>">末页</a>
            <?php endif; ?>
        </div>
    <?php endif; ?>
</body>

</html>