<?php
// 引入数据库配置文件
require_once '../config.php';

// 数据库连接
$conn = get_db_connection();

// 验证必填字段
if (!isset($_POST['transaction_date']) || empty($_POST['transaction_date'])) {
    echo "❌ 错误: 交易日期不能为空";
    exit;
}

if (!isset($_POST['record_type']) || empty($_POST['record_type'])) {
    echo "❌ 错误: 记录类型不能为空";
    exit;
}

if (!isset($_POST['amount']) || empty($_POST['amount'])) {
    echo "❌ 错误: 交易金额不能为空";
    exit;
}

// 获取表单数据
$transaction_date = $_POST['transaction_date'];
$record_type = $_POST['record_type'];
$amount = floatval($_POST['amount']);
$description = $_POST['description'] ?? '';
$category = $_POST['category'] ?? '';
$payment_method = $_POST['payment_method'] ?? '';
$created_by = isset($_SESSION['user']['id']) ? $_SESSION['user']['id'] : null;

// 检查金额是否为正数
if ($amount <= 0) {
    echo "❌ 错误: 交易金额必须大于0";
    exit;
}

// 准备SQL语句
$sql = "INSERT INTO financial_records (
            created_at, 
            record_type, 
            amount, 
            description, 
            category, 
            payment_method,
            created_by
        ) VALUES (?, ?, ?, ?, ?, ?, ?)";

$stmt = $conn->prepare($sql);

// 绑定参数
$stmt->bind_param(
    "ssdsssj",
    $transaction_date,
    $record_type,
    $amount,
    $description,
    $category,
    $payment_method,
    $created_by
);

// 执行插入
if ($stmt->execute()) {
    // 检查是否是批量添加模式
    $batchAdd = isset($_POST['batch_add']) && $_POST['batch_add'] == 1;

    echo "✅ 财务记录保存成功！";

    // 如果是批量添加，可以在此添加额外的处理逻辑
} else {
    echo "❌ 错误: " . $stmt->error;
}

$stmt->close();
$conn->close();
