<?php
session_start();
if (!isset($_SESSION['user'])) {
    header("Location: ../login.php");
    exit;
}

// 引入数据库配置文件
require_once '../config.php';

// 数据库连接
$conn = get_db_connection();

// 确定视图类型（默认按商品视图）
$view_type = isset($_GET['view']) ? $_GET['view'] : 'product';

// 是否显示所有商品（包括库存为零的）- 仅影响仓库视图
$show_all_products = isset($_GET['show_all']) && $_GET['show_all'] == '1';

// 搜索条件
$search = isset($_GET['search']) ? trim($_GET['search']) : '';
$searchCondition = "";

if (!empty($search)) {
    $search = $conn->real_escape_string($search);
    $searchCondition = " AND (p.product_name LIKE '%$search%' OR p.product_code LIKE '%$search%')";
}

// 分页参数
$page = isset($_GET['page']) ? intval($_GET['page']) : 1;
$page_size = 10; // 每页显示10条记录
$offset = ($page - 1) * $page_size;

// 获取库存数据
if ($view_type == 'product') {
    // 获取总记录数
    $countSql = "SELECT COUNT(*) as total FROM products p WHERE 1=1";

    if (!empty($search)) {
        $countSql .= $searchCondition;
    }

    $countResult = $conn->query($countSql);
    $totalRecords = $countResult->fetch_assoc()['total'];
    $totalPages = ceil($totalRecords / $page_size);

    // 检查inventory_stock表是否存在
    $tableCheckResult = $conn->query("SHOW TABLES LIKE 'inventory_stock'");
    $inventoryStockExists = $tableCheckResult->num_rows > 0;

    // 检查product_units表是否存在
    $tableCheckResult = $conn->query("SHOW TABLES LIKE 'product_units'");
    $productUnitsExists = $tableCheckResult->num_rows > 0;

    // Redis缓存实现
    $redisManager = get_redis_instance();
    $cacheKey = "inventory:product:{$page}:{$page_size}:{$show_all_products}:" . md5($search);

    // 检查是否需要强制刷新缓存
    $forceRefresh = isset($_GET['refresh']) && $_GET['refresh'] == '1';

    // Redis调试信息
    $redisDebug = [
        'available' => false,
        'cache_key' => $cacheKey,
        'cache_hit' => false,
        'time_saved' => 0,
        'redis_prefix' => $redis_prefix ?? '',
        'full_key' => ($redis_prefix ?? '') . $cacheKey,
        'expiry' => 300,
        'force_refresh' => $forceRefresh
    ];

    // 添加Redis可用性检查
    $products = null;
    $startTime = microtime(true);
    if (!$forceRefresh && $redisManager->isAvailable()) {
        $redisDebug['available'] = true;
        // 尝试从缓存获取
        $products = $redisManager->get($cacheKey);
        if ($products) {
            $redisDebug['cache_hit'] = true;
            $redisDebug['time_saved'] = microtime(true) - $startTime;
        }
    }

    if (!$products) {
        // 缓存未命中或需强制刷新，从数据库获取
        $dbStartTime = microtime(true);

        // 按产品视图 - 根据数据库情况调整SQL
        if ($inventoryStockExists && $productUnitsExists) {
            // 先选出10个产品，再获取它们的详细信息
            $productIdsSql = "
            SELECT DISTINCT
                p.id
            FROM 
                products p
            WHERE 1=1
            ";

            if (!empty($search)) {
                $productIdsSql .= $searchCondition;
            }

            $productIdsSql .= "
            ORDER BY 
                p.id DESC
            LIMIT ?, ?
            ";

            $productIdsStmt = $conn->prepare($productIdsSql);
            $productIdsStmt->bind_param("ii", $offset, $page_size);
            $productIdsStmt->execute();
            $productIdsResult = $productIdsStmt->get_result();

            $selectedProductIds = [];
            while ($row = $productIdsResult->fetch_assoc()) {
                $selectedProductIds[] = $row['id'];
            }
            $productIdsStmt->close();

            if (empty($selectedProductIds)) {
                $products = [];
            } else {
                // 完整查询 - 两个表都存在，只获取上面查询到的产品ID
                $sql = "
                SELECT 
                    p.id as product_id,
                    p.product_code,
                    p.product_name,
                    p.unit,
                    p.multi_unit,
                    w.id as warehouse_id,
                    w.name as warehouse_name,
                    COALESCE(s.base_quantity, 0) as stock_quantity,
                    base_pu.unit_name as base_unit_name,
                    (SELECT GROUP_CONCAT(
                        CONCAT(sub.unit_name, ':', ROUND(COALESCE(s.base_quantity, 0) / sub.ratio, 2))
                        SEPARATOR '|'
                    ) FROM product_units sub WHERE sub.product_id = p.id AND sub.unit_type = 'sub') as sub_units
                FROM 
                    products p
                LEFT JOIN 
                    inventory_stock s ON p.id = s.product_id
                LEFT JOIN 
                    warehouses w ON s.warehouse_id = w.id
                LEFT JOIN 
                    product_units base_pu ON p.id = base_pu.product_id AND base_pu.unit_type = 'base'
                WHERE 
                    p.id IN (" . implode(',', $selectedProductIds) . ")
                ORDER BY 
                    p.id DESC
                ";

                $stmt = $conn->prepare($sql);
                $stmt->execute();
                $result = $stmt->get_result();

                $products_temp = [];
                while ($row = $result->fetch_assoc()) {
                    $products_temp[] = $row;
                }
                $stmt->close();
                $products = $products_temp;
            }
        } elseif ($inventoryStockExists) {
            // 先选出10个产品，再获取它们的详细信息
            $productIdsSql = "
            SELECT DISTINCT
                p.id
            FROM 
                products p
            WHERE 1=1
            ";

            if (!empty($search)) {
                $productIdsSql .= $searchCondition;
            }

            $productIdsSql .= "
            ORDER BY 
                p.id DESC
            LIMIT ?, ?
            ";

            $productIdsStmt = $conn->prepare($productIdsSql);
            $productIdsStmt->bind_param("ii", $offset, $page_size);
            $productIdsStmt->execute();
            $productIdsResult = $productIdsStmt->get_result();

            $selectedProductIds = [];
            while ($row = $productIdsResult->fetch_assoc()) {
                $selectedProductIds[] = $row['id'];
            }
            $productIdsStmt->close();

            if (empty($selectedProductIds)) {
                $products = [];
            } else {
                // 简化查询 - 只有inventory_stock表存在
                $sql = "
                SELECT 
                    p.id as product_id,
                    p.product_code,
                    p.product_name,
                    p.unit,
                    p.multi_unit,
                    w.id as warehouse_id,
                    w.name as warehouse_name,
                    COALESCE(s.base_quantity, 0) as stock_quantity
                FROM 
                    products p
                LEFT JOIN 
                    inventory_stock s ON p.id = s.product_id
                LEFT JOIN 
                    warehouses w ON s.warehouse_id = w.id
                WHERE 
                    p.id IN (" . implode(',', $selectedProductIds) . ")
                ORDER BY 
                    p.id DESC
                ";

                $stmt = $conn->prepare($sql);
                $stmt->execute();
                $result = $stmt->get_result();

                $products_temp = [];
                while ($row = $result->fetch_assoc()) {
                    $products_temp[] = $row;
                }
                $stmt->close();
                $products = $products_temp;
            }
        } else {
            // 最简化查询 - 没有任何相关表
            $sql = "
            SELECT DISTINCT
                p.id as product_id,
                p.product_code,
                p.product_name,
                p.unit,
                p.multi_unit
            FROM 
                products p
            WHERE 1=1
            ";

            if (!empty($search)) {
                $sql .= $searchCondition;
            }

            $sql .= "
            ORDER BY 
                p.id DESC
            LIMIT ?, ?
            ";

            $stmt = $conn->prepare($sql);
            $stmt->bind_param("ii", $offset, $page_size);
            $stmt->execute();
            $result = $stmt->get_result();

            $products_temp = [];
            while ($row = $result->fetch_assoc()) {
                $products_temp[] = $row;
            }
            $stmt->close();
            $products = $products_temp;
        }

        $redisDebug['db_query_time'] = microtime(true) - $dbStartTime;

        // 只在Redis可用时缓存结果
        if ($redisManager->isAvailable()) {
            $redisDebug['cache_set'] = true;
            $redisManager->set($cacheKey, $products, 300); // 缓存5分钟
        }
    }

    // 格式化处理产品数据用于显示
    $formattedProducts = [];
    if (!empty($products)) {
        foreach ($products as $row) {
            $productId = $row['product_id'];

            if (!isset($formattedProducts[$productId])) {
                $formattedProducts[$productId] = [
                    'id' => $productId,
                    'product_code' => $row['product_code'],
                    'product_name' => $row['product_name'],
                    'unit' => $row['unit'],
                    'multi_unit' => $row['multi_unit'],
                    'base_unit_name' => isset($row['base_unit_name']) ? $row['base_unit_name'] : $row['unit'],
                    'warehouses' => []
                ];
            }

            if (isset($row['warehouse_id']) && $row['warehouse_id']) {
                $warehouseData = [
                    'id' => $row['warehouse_id'],
                    'name' => $row['warehouse_name'],
                    'quantity' => $row['stock_quantity']
                ];

                if (isset($row['sub_units'])) {
                    $warehouseData['sub_units'] = $row['sub_units'];
                }

                $formattedProducts[$productId]['warehouses'][] = $warehouseData;
            }
        }
    }

    $products = $formattedProducts;
} else {
    // 获取总记录数
    $countSql = "SELECT COUNT(*) as total FROM warehouses";
    $countResult = $conn->query($countSql);
    $totalRecords = $countResult->fetch_assoc()['total'];
    $totalPages = ceil($totalRecords / $page_size);

    // 查询所有仓库用于显示切换按钮
    $allWarehousesResult = $conn->query("SELECT id, name FROM warehouses ORDER BY name");
    $allWarehouses = [];
    if ($allWarehousesResult) {
        while ($warehouse = $allWarehousesResult->fetch_assoc()) {
            $allWarehouses[] = $warehouse;
        }
    }

    // 确定当前选中的仓库
    $selected_warehouse_id = isset($_GET['warehouse_id']) ? intval($_GET['warehouse_id']) : (!empty($allWarehouses) ? $allWarehouses[0]['id'] : 0);

    // 如果有选定的仓库，获取该仓库的库存数据
    if ($selected_warehouse_id > 0) {
        // 检查inventory_stock表是否存在
        $tableCheckResult = $conn->query("SHOW TABLES LIKE 'inventory_stock'");
        $inventoryStockExists = $tableCheckResult->num_rows > 0;

        // 检查product_units表是否存在
        $tableCheckResult = $conn->query("SHOW TABLES LIKE 'product_units'");
        $productUnitsExists = $tableCheckResult->num_rows > 0;

        // 获取仓库信息
        $warehouseResult = $conn->query("SELECT id, name FROM warehouses WHERE id = $selected_warehouse_id");
        $selectedWarehouse = $warehouseResult->fetch_assoc();

        // 获取该仓库的商品库存，添加分页
        if ($inventoryStockExists && $productUnitsExists) {
            // 计算该仓库的产品总数
            if ($show_all_products) {
                // 显示所有商品，包括无库存的
                $countProductSql = "SELECT COUNT(DISTINCT p.id) as total 
                                   FROM products p 
                                   LEFT JOIN inventory_stock s ON p.id = s.product_id AND s.warehouse_id = $selected_warehouse_id
                                   WHERE 1=1";
            } else {
                // 只显示有库存的商品
                $countProductSql = "SELECT COUNT(DISTINCT p.id) as total 
                                   FROM products p 
                                   JOIN inventory_stock s ON p.id = s.product_id 
                                   WHERE s.warehouse_id = $selected_warehouse_id
                                   AND s.base_quantity > 0";
            }

            if (!empty($search)) {
                $countProductSql .= " AND (p.product_name LIKE '%$search%' OR p.product_code LIKE '%$search%')";
            }

            $countProductResult = $conn->query($countProductSql);
            $totalProductsInWarehouse = $countProductResult->fetch_assoc()['total'];
            $totalPages = ceil($totalProductsInWarehouse / $page_size);

            // 完整查询获取当前页的商品
            if ($show_all_products) {
                // 显示所有商品SQL
                $sql = "
                SELECT DISTINCT
                    p.id as product_id,
                    p.product_code,
                    p.product_name,
                    p.unit,
                    p.multi_unit,
                    COALESCE(s.base_quantity, 0) as stock_quantity,
                    base_pu.unit_name as base_unit_name,
                    (SELECT GROUP_CONCAT(
                        CONCAT(sub.unit_name, ':', ROUND(COALESCE(s.base_quantity, 0) / sub.ratio, 1))
                        SEPARATOR '|'
                    ) FROM product_units sub WHERE sub.product_id = p.id AND sub.unit_type = 'sub') as sub_units
                FROM 
                    products p
                LEFT JOIN 
                    inventory_stock s ON p.id = s.product_id AND s.warehouse_id = ?
                LEFT JOIN 
                    product_units base_pu ON p.id = base_pu.product_id AND base_pu.unit_type = 'base'
                WHERE 1=1
                ";
            } else {
                // 只显示有库存的商品SQL
                $sql = "
                SELECT DISTINCT
                    p.id as product_id,
                    p.product_code,
                    p.product_name,
                    p.unit,
                    p.multi_unit,
                    COALESCE(s.base_quantity, 0) as stock_quantity,
                    base_pu.unit_name as base_unit_name,
                    (SELECT GROUP_CONCAT(
                        CONCAT(sub.unit_name, ':', ROUND(COALESCE(s.base_quantity, 0) / sub.ratio, 1))
                        SEPARATOR '|'
                    ) FROM product_units sub WHERE sub.product_id = p.id AND sub.unit_type = 'sub') as sub_units
                FROM 
                    products p
                JOIN 
                    inventory_stock s ON p.id = s.product_id
                LEFT JOIN 
                    product_units base_pu ON p.id = base_pu.product_id AND base_pu.unit_type = 'base'
                WHERE 
                    s.warehouse_id = ?
                    AND s.base_quantity > 0
                ";
            }

            if (!empty($search)) {
                $sql .= " AND (p.product_name LIKE '%$search%' OR p.product_code LIKE '%$search%')";
            }

            $sql .= "
            ORDER BY 
                p.id DESC
            LIMIT ?, ?
            ";

            $stmt = $conn->prepare($sql);

            if ($show_all_products) {
                $stmt->bind_param("iii", $selected_warehouse_id, $offset, $page_size);
            } else {
                $stmt->bind_param("iii", $selected_warehouse_id, $offset, $page_size);
            }
        } elseif ($inventoryStockExists) {
            // 简化查询
            // 计算产品数
            if ($show_all_products) {
                $countProductSql = "SELECT COUNT(DISTINCT p.id) as total 
                                   FROM products p 
                                   LEFT JOIN inventory_stock s ON p.id = s.product_id AND s.warehouse_id = $selected_warehouse_id
                                   WHERE 1=1";
            } else {
                $countProductSql = "SELECT COUNT(DISTINCT p.id) as total 
                                   FROM products p 
                                   JOIN inventory_stock s ON p.id = s.product_id 
                                   WHERE s.warehouse_id = $selected_warehouse_id
                                   AND s.base_quantity > 0";
            }

            if (!empty($search)) {
                $countProductSql .= " AND (p.product_name LIKE '%$search%' OR p.product_code LIKE '%$search%')";
            }

            $countProductResult = $conn->query($countProductSql);
            $totalProductsInWarehouse = $countProductResult->fetch_assoc()['total'];
            $totalPages = ceil($totalProductsInWarehouse / $page_size);

            if ($show_all_products) {
                $sql = "
                SELECT DISTINCT
                    p.id as product_id,
                    p.product_code,
                    p.product_name,
                    p.unit,
                    p.multi_unit,
                    COALESCE(s.base_quantity, 0) as stock_quantity
                FROM 
                    products p
                LEFT JOIN 
                    inventory_stock s ON p.id = s.product_id AND s.warehouse_id = ?
                WHERE 1=1
                ";
            } else {
                $sql = "
                SELECT DISTINCT
                    p.id as product_id,
                    p.product_code,
                    p.product_name,
                    p.unit,
                    p.multi_unit,
                    COALESCE(s.base_quantity, 0) as stock_quantity
                FROM 
                    products p
                JOIN 
                    inventory_stock s ON p.id = s.product_id
                WHERE 
                    s.warehouse_id = ?
                    AND s.base_quantity > 0
                ";
            }

            if (!empty($search)) {
                $sql .= " AND (p.product_name LIKE '%$search%' OR p.product_code LIKE '%$search%')";
            }

            $sql .= "
            ORDER BY 
                p.id DESC
            LIMIT ?, ?
            ";

            $stmt = $conn->prepare($sql);

            if ($show_all_products) {
                $stmt->bind_param("iii", $selected_warehouse_id, $offset, $page_size);
            } else {
                $stmt->bind_param("iii", $selected_warehouse_id, $offset, $page_size);
            }
        } else {
            // 最简查询 - 不涉及库存
            $sql = "
            SELECT DISTINCT
                p.id as product_id,
                p.product_code,
                p.product_name,
                p.unit,
                p.multi_unit
            FROM 
                products p
            WHERE 1=1
            ";

            if (!empty($search)) {
                $sql .= $searchCondition;
            }

            $sql .= "
            ORDER BY 
                p.id DESC
            LIMIT ?, ?
            ";

            $stmt = $conn->prepare($sql);
            $stmt->bind_param("ii", $offset, $page_size);
        }

        $stmt->execute();
        $result = $stmt->get_result();

        $warehouseProducts = [];

        if ($result) {
            while ($row = $result->fetch_assoc()) {
                $warehouseProducts[] = [
                    'id' => $row['product_id'],
                    'product_code' => $row['product_code'],
                    'product_name' => $row['product_name'],
                    'unit' => $row['unit'],
                    'multi_unit' => $row['multi_unit'] ?? 0,
                    'base_unit_name' => $row['base_unit_name'] ?? $row['unit'],
                    'quantity' => $row['stock_quantity'] ?? 0,
                    'sub_units' => $row['sub_units'] ?? ''
                ];
            }
        }

        $selectedWarehouse['products'] = $warehouseProducts;
    } else {
        $selectedWarehouse = null;
    }
}

// 关闭数据库连接
$conn->close();
?>
<!DOCTYPE html>
<html lang="zh">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>库存列表</title>
    <link rel="stylesheet" href="./style.css">
    <link rel="stylesheet" href="./css/inventory_stock.css">
</head>

<body>
    <div class="header">
        <h2>库存列表</h2>
        <div class="button-group">
            <a href="inventory_transfer_form.php" class="btn btn-add" style="margin-right: 10px;">库存调拨</a>
            <a href="inventory_in_form.php" class="btn btn-add">商品入库</a>
        </div>
    </div>

    <!-- 消息显示区域 -->
    <?php if (isset($_GET['message']) && !empty($_GET['message'])): ?>
        <div id="message-container" class="message" style="display: flex;">
            <span id="message-text"><?= htmlspecialchars($_GET['message']) ?></span>
            <button onclick="document.getElementById('message-container').style.display='none'">×</button>
        </div>
    <?php endif; ?>

    <!-- 添加搜索表单 -->
    <form action="" method="get" class="search-box">
        <input type="text" name="search" placeholder="搜索商品名称/编号" value="<?= htmlspecialchars($search) ?>">
        <input type="hidden" name="view" value="<?= $view_type ?>">
        <button type="submit">搜索</button>
    </form>
    <div class="container">

        <div class="view-toggle">
            <a href="?view=product<?= !empty($search) ? '&search=' . urlencode($search) : '' ?>" class="view-btn <?= $view_type == 'product' ? 'active' : '' ?>">按商品查看</a>
            <a href="?view=warehouse<?= !empty($search) ? '&search=' . urlencode($search) : '' ?>" class="view-btn <?= $view_type == 'warehouse' ? 'active' : '' ?>">按仓库查看</a>
        </div>

        <?php if ($view_type == 'product'): ?>
            <!-- 按商品视图 -->
            <div class="table-container">
                <table>
                    <thead>
                        <tr>
                            <th width="120">商品编号</th>
                            <th>商品名称</th>
                            <?php
                            // 查询所有仓库作为表头
                            $warehouseResult = $conn = get_db_connection()->query("SELECT id, name FROM warehouses ORDER BY name");
                            $warehouses = [];
                            if ($warehouseResult) {
                                while ($warehouse = $warehouseResult->fetch_assoc()) {
                                    $warehouses[] = $warehouse;
                                    echo "<th width='120'>" . htmlspecialchars($warehouse['name']) . "</th>";
                                }
                            }
                            ?>
                            <th width="100">总库存</th>
                            <th width="80">操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($products)): ?>
                            <tr>
                                <td colspan="<?= 3 + count($warehouses) ?>" style="text-align: center;">暂无库存数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($products as $product): ?>
                                <tr>
                                    <td><?= htmlspecialchars($product['product_code']) ?></td>
                                    <td><?= htmlspecialchars($product['product_name']) ?></td>

                                    <?php
                                    $totalStock = 0;
                                    foreach ($warehouses as $warehouse) {
                                        $found = false;
                                        foreach ($product['warehouses'] as $pw) {
                                            if ($pw['id'] == $warehouse['id']) {
                                                $quantity = floatval($pw['quantity']);
                                                $totalStock += $quantity;
                                                $stockClass = $quantity <= 0 ? 'stock-zero' : ($quantity < 10 ? 'stock-low' : 'stock-normal');

                                                echo "<td class='$stockClass'>";
                                                // 基本单位显示
                                                $baseUnitName = $product['base_unit_name'] ?: $product['unit'];
                                                if (empty($baseUnitName)) {
                                                    $baseUnitName = '件'; // 默认单位
                                                }
                                                echo '<span class="unit-line">' . floor($quantity) . " " . $baseUnitName . '</span>';

                                                // 如果有副单位，显示换算后的数量
                                                if (!empty($pw['sub_units'])) {
                                                    $subUnitsArray = explode('|', $pw['sub_units']);
                                                    foreach ($subUnitsArray as $subUnit) {
                                                        if (!empty($subUnit)) {
                                                            // 转换副单位显示格式
                                                            list($unitName, $value) = explode(':', $subUnit);
                                                            echo '<span class="unit-line">' . $value . " " . $unitName . '</span>';
                                                        }
                                                    }
                                                }

                                                echo "</td>";
                                                $found = true;
                                                break;
                                            }
                                        }
                                        if (!$found) {
                                            $baseUnitName = $product['base_unit_name'] ?: $product['unit'];
                                            if (empty($baseUnitName)) {
                                                $baseUnitName = '件'; // 默认单位
                                            }
                                            echo "<td class='stock-zero'>0 " . $baseUnitName . "</td>";
                                        }
                                    }

                                    // 总库存
                                    $totalStockClass = $totalStock <= 0 ? 'stock-zero' : ($totalStock < 10 ? 'stock-low' : 'stock-normal');
                                    ?>
                                    <td class="<?= $totalStockClass ?>">
                                        <?php
                                        // 基本单位显示
                                        $baseUnitName = $product['base_unit_name'] ?: $product['unit'];
                                        if (empty($baseUnitName)) {
                                            $baseUnitName = '件'; // 默认单位
                                        }
                                        echo '<span class="unit-line">' . floor($totalStock) . " " . $baseUnitName . '</span>';

                                        // 计算并显示副单位下的总库存
                                        if ($product['multi_unit'] && !empty($product['warehouses']) && isset($product['warehouses'][0]['sub_units'])) {
                                            // 获取第一个仓库的副单位信息作为模板
                                            $firstWarehouse = $product['warehouses'][0];
                                            if (!empty($firstWarehouse['sub_units'])) {
                                                $subUnitsArray = explode('|', $firstWarehouse['sub_units']);

                                                // 对于每个副单位，计算总库存并显示
                                                foreach ($subUnitsArray as $subUnit) {
                                                    if (!empty($subUnit)) {
                                                        // 从副单位中提取单位名称和比率
                                                        list($unitName, $ignored) = explode(':', $subUnit);

                                                        // 查询该副单位的比率
                                                        $conn = get_db_connection();
                                                        $unitStmt = $conn->prepare("SELECT ratio FROM product_units WHERE product_id = ? AND unit_type = 'sub' AND unit_name = ?");
                                                        $unitStmt->bind_param("is", $product['id'], $unitName);
                                                        $unitStmt->execute();
                                                        $unitResult = $unitStmt->get_result();

                                                        if ($unitResult->num_rows > 0) {
                                                            $ratio = $unitResult->fetch_assoc()['ratio'];
                                                            // 计算副单位下的总数量
                                                            $subUnitTotal = $totalStock / $ratio;
                                                            echo '<span class="unit-line">' . number_format($subUnitTotal, 2) . " " . $unitName . '</span>';
                                                        }
                                                    }
                                                }
                                            }
                                        }
                                        ?>
                                    </td>
                                    <td class="operation-cell">
                                        <a href="edit_inventory.php?product_id=<?= $product['id'] ?>&view=product" class="btn btn-sm">编辑</a>
                                        <a href="inventory_transfer_form.php?product_id=<?= $product['id'] ?>" class="btn btn-sm btn-transfer">调拨</a>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 分页导航 -->
            <?php if ($totalPages > 1): ?>
                <div class="pagination">
                    <?php if ($page > 1): ?>
                        <a href="?view=<?= $view_type ?>&page=1<?= !empty($search) ? '&search=' . urlencode($search) : '' ?>">首页</a>
                        <a href="?view=<?= $view_type ?>&page=<?= $page - 1 ?><?= !empty($search) ? '&search=' . urlencode($search) : '' ?>">上一页</a>
                    <?php endif; ?>

                    <?php
                    // 显示页码范围
                    $startPage = max(1, $page - 2);
                    $endPage = min($totalPages, $page + 2);

                    for ($i = $startPage; $i <= $endPage; $i++):
                    ?>
                        <?php if ($i == $page): ?>
                            <span class="current"><?= $i ?></span>
                        <?php else: ?>
                            <a href="?view=<?= $view_type ?>&page=<?= $i ?><?= !empty($search) ? '&search=' . urlencode($search) : '' ?>"><?= $i ?></a>
                        <?php endif; ?>
                    <?php endfor; ?>

                    <?php if ($page < $totalPages): ?>
                        <a href="?view=<?= $view_type ?>&page=<?= $page + 1 ?><?= !empty($search) ? '&search=' . urlencode($search) : '' ?>">下一页</a>
                        <a href="?view=<?= $view_type ?>&page=<?= $totalPages ?><?= !empty($search) ? '&search=' . urlencode($search) : '' ?>">末页</a>
                    <?php endif; ?>
                </div>
            <?php endif; ?>
        <?php else: ?>
            <!-- 按仓库视图 -->
            <?php if (empty($allWarehouses)): ?>
                <div style="text-align: center; padding: 20px;">暂无仓库数据</div>
            <?php else: ?>
                <!-- 仓库切换菜单 -->
                <div class="warehouse-toggle" style="margin-bottom: 20px; display: flex; gap: 10px; flex-wrap: wrap;">
                    <?php foreach ($allWarehouses as $warehouse): ?>
                        <a href="?view=warehouse&warehouse_id=<?= $warehouse['id'] ?><?= !empty($search) ? '&search=' . urlencode($search) : '' ?>"
                            class="view-btn <?= $selected_warehouse_id == $warehouse['id'] ? 'active' : '' ?>">
                            <?= htmlspecialchars($warehouse['name']) ?>
                        </a>
                    <?php endforeach; ?>
                </div>

                <?php if ($selectedWarehouse): ?>
                    <div style="display: flex; justify-content: space-between; align-items: center; margin-bottom: 15px;">
                        <h3><?= htmlspecialchars($selectedWarehouse['name']) ?> - 库存明细</h3>
                        <div class="show-all-toggle">
                            <a href="?view=warehouse&warehouse_id=<?= $selected_warehouse_id ?>&show_all=<?= $show_all_products ? '0' : '1' ?><?= !empty($search) ? '&search=' . urlencode($search) : '' ?>" class="btn btn-sm">
                                <?= $show_all_products ? '仅显示有库存商品' : '显示所有商品' ?>
                            </a>
                        </div>
                    </div>
                    <div class="table-container" style="margin-bottom: 30px;">
                        <table>
                            <thead>
                                <tr>
                                    <th width="120">商品编号</th>
                                    <th>商品名称</th>
                                    <th width="120">库存数量</th>
                                    <th width="80">操作</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php if (empty($selectedWarehouse['products'])): ?>
                                    <tr>
                                        <td colspan="4" style="text-align: center;">该仓库暂无库存</td>
                                    </tr>
                                <?php else: ?>
                                    <?php foreach ($selectedWarehouse['products'] as $product): ?>
                                        <tr>
                                            <td><?= htmlspecialchars($product['product_code']) ?></td>
                                            <td><?= htmlspecialchars($product['product_name']) ?></td>
                                            <?php
                                            $quantity = floatval($product['quantity']);
                                            $stockClass = $quantity <= 0 ? 'stock-zero' : ($quantity < 10 ? 'stock-low' : 'stock-normal');
                                            ?>
                                            <td class="<?= $stockClass ?>">
                                                <?php
                                                // 基本单位显示
                                                $baseUnitName = $product['base_unit_name'] ?: $product['unit'];
                                                if (empty($baseUnitName)) {
                                                    $baseUnitName = '件'; // 默认单位
                                                }
                                                echo '<span class="unit-line">' . floor($quantity) . " " . $baseUnitName . '</span>';

                                                // 如果有副单位，显示换算后的数量
                                                if (!empty($product['sub_units'])) {
                                                    $subUnitsArray = explode('|', $product['sub_units']);
                                                    foreach ($subUnitsArray as $subUnit) {
                                                        if (!empty($subUnit)) {
                                                            // 转换副单位显示格式
                                                            list($unitName, $value) = explode(':', $subUnit);
                                                            echo '<span class="unit-line">' . $value . " " . $unitName . '</span>';
                                                        }
                                                    }
                                                }
                                                ?>
                                            </td>
                                            <td class="operation-cell">
                                                <a href="edit_inventory.php?product_id=<?= $product['id'] ?>&warehouse_id=<?= $selectedWarehouse['id'] ?>&view=warehouse" class="btn btn-sm">编辑</a>
                                                <a href="inventory_transfer_form.php?product_id=<?= $product['id'] ?>&warehouse_id=<?= $selectedWarehouse['id'] ?>" class="btn btn-sm btn-transfer">调拨</a>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                <?php endif; ?>
                            </tbody>
                        </table>
                    </div>
                <?php endif; ?>
            <?php endif; ?>

            <!-- 分页导航 -->
            <?php if ($totalPages > 1): ?>
                <div class="pagination">
                    <?php if ($page > 1): ?>
                        <a href="?view=<?= $view_type ?>&warehouse_id=<?= $selected_warehouse_id ?>&show_all=<?= $show_all_products ? '1' : '0' ?>&page=1<?= !empty($search) ? '&search=' . urlencode($search) : '' ?>">首页</a>
                        <a href="?view=<?= $view_type ?>&warehouse_id=<?= $selected_warehouse_id ?>&show_all=<?= $show_all_products ? '1' : '0' ?>&page=<?= $page - 1 ?><?= !empty($search) ? '&search=' . urlencode($search) : '' ?>">上一页</a>
                    <?php endif; ?>

                    <?php
                    // 显示页码范围
                    $startPage = max(1, $page - 2);
                    $endPage = min($totalPages, $page + 2);

                    for ($i = $startPage; $i <= $endPage; $i++):
                    ?>
                        <?php if ($i == $page): ?>
                            <span class="current"><?= $i ?></span>
                        <?php else: ?>
                            <a href="?view=<?= $view_type ?>&warehouse_id=<?= $selected_warehouse_id ?>&show_all=<?= $show_all_products ? '1' : '0' ?>&page=<?= $i ?><?= !empty($search) ? '&search=' . urlencode($search) : '' ?>"><?= $i ?></a>
                        <?php endif; ?>
                    <?php endfor; ?>

                    <?php if ($page < $totalPages): ?>
                        <a href="?view=<?= $view_type ?>&warehouse_id=<?= $selected_warehouse_id ?>&show_all=<?= $show_all_products ? '1' : '0' ?>&page=<?= $page + 1 ?><?= !empty($search) ? '&search=' . urlencode($search) : '' ?>">下一页</a>
                        <a href="?view=<?= $view_type ?>&warehouse_id=<?= $selected_warehouse_id ?>&show_all=<?= $show_all_products ? '1' : '0' ?>&page=<?= $totalPages ?><?= !empty($search) ? '&search=' . urlencode($search) : '' ?>">末页</a>
                    <?php endif; ?>
                </div>
            <?php endif; ?>
        <?php endif; ?>
    </div>

    <script>
        // 自动关闭消息提示
        setTimeout(() => {
            const messageBox = document.getElementById('message-container');
            if (messageBox) {
                messageBox.style.display = 'none';
            }
        }, 5000);

        // Redis调试信息输出到控制台
        console.log('========== Redis缓存调试信息 ==========');
        console.log('Redis可用: <?= isset($redisDebug) && $redisDebug['available'] ? '是' : '否' ?>');
        console.log('缓存键名: <?= isset($redisDebug) ? $redisDebug['cache_key'] : '未使用' ?>');
        console.log('带前缀的完整键名: <?= isset($redisDebug) ? $redisDebug['full_key'] : '未使用' ?>');
        console.log('缓存命中: <?= isset($redisDebug) && $redisDebug['cache_hit'] ? '是' : '否' ?>');
        <?php if (isset($redisDebug) && $redisDebug['cache_hit']): ?>
            console.log('节省查询时间: <?= number_format($redisDebug['time_saved'] * 1000, 2) ?> 毫秒');
        <?php else: ?>
            console.log('数据库查询时间: <?= isset($redisDebug) && isset($redisDebug['db_query_time']) ? number_format($redisDebug['db_query_time'] * 1000, 2) : 0 ?> 毫秒');
            console.log('缓存结果: <?= isset($redisDebug) && isset($redisDebug['cache_set']) && $redisDebug['cache_set'] ? '是' : '否' ?>');
        <?php endif; ?>
        console.log('缓存过期时间: <?= isset($redisDebug) ? $redisDebug['expiry'] : '0' ?> 秒');
        console.log('强制刷新: <?= isset($redisDebug) && $redisDebug['force_refresh'] ? '是' : '否' ?>');
        console.log('========================================');
    </script>
</body>

</html>