<?php
// login.php
session_start();

// 如果已登录，跳转首页
if (isset($_SESSION['user'])) {
    header("Location: home.php");
    exit;
}

// 引入数据库配置文件
require_once 'config.php';

$error = '';
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $username = $_POST['username'] ?? '';
    $password = $_POST['password'] ?? '';

    // 数据库连接
    $conn = get_db_connection();

    $stmt = $conn->prepare("SELECT id, username, password, role, real_name FROM users WHERE username = ? AND is_active = 1");
    $stmt->bind_param("s", $username);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($user = $result->fetch_assoc()) {
        if (password_verify($password, $user['password'])) {
            $_SESSION['user'] = [
                'id' => $user['id'],
                'username' => $user['username'],
                'role' => $user['role'],
                'real_name' => $user['real_name']
            ];
            header("Location: home.php");
            exit;
        } else {
            $error = "密码错误";
        }
    } else {
        $error = "用户不存在或已被禁用";
    }
}
?>
<!DOCTYPE html>
<html lang="zh">

<head>
    <meta charset="UTF-8">
    <title>CA417-副食品行业进销存管理系统 - 登录</title>
    <style>
        body {
            font-family: Arial;
            background: linear-gradient(135deg, #7fd978, #2b9348);
            display: flex;
            justify-content: center;
            align-items: center;
            height: 100vh;
            margin: 0;
        }

        .login-box {
            background: white;
            padding: 30px;
            border-radius: 8px;
            box-shadow: 0 0 20px rgba(0, 0, 0, 0.2);
            width: 320px;
        }

        .system-title {
            text-align: center;
            font-size: 30px;
            font-weight: bold;
            color: #333;
            margin-bottom: 15px;
            padding-bottom: 15px;
            border-bottom: 1px solid #eee;
        }

        h2 {
            margin-bottom: 25px;
            text-align: center;
            color: #2b9348;
        }

        .form-group {
            margin-bottom: 20px;
            position: relative;
        }

        input {
            width: 100%;
            padding: 12px 15px;
            border: 1px solid #ddd;
            border-radius: 4px;
            box-sizing: border-box;
            font-size: 14px;
            transition: border-color 0.3s;
        }

        input:focus {
            border-color: #2b9348;
            outline: none;
            box-shadow: 0 0 5px rgba(43, 147, 72, 0.3);
        }

        button {
            width: 100%;
            padding: 12px;
            background: #2b9348;
            border: none;
            color: white;
            border-radius: 4px;
            cursor: pointer;
            font-size: 16px;
            transition: background 0.3s;
        }

        button:hover {
            background: #3c8c51;
        }

        .error {
            color: #e74c3c;
            text-align: center;
            margin-bottom: 15px;
            background: #ffeaea;
            padding: 8px;
            border-radius: 4px;
            font-size: 14px;
        }
    </style>
</head>

<body>
    <div class="login-box">
        <div class="system-title">CA417-副食品行业进销存管理系统</div>
        <h2>用户登录</h2>
        <?php if ($error): ?><div class="error"><?= htmlspecialchars($error) ?></div><?php endif; ?>
        <form method="post">
            <div class="form-group">
                <input type="text" name="username" placeholder="用户名" required>
            </div>
            <div class="form-group">
                <input type="password" name="password" placeholder="密码" required>
            </div>
            <button type="submit">登录</button>
        </form>
    </div>
</body>

</html>