<?php
// 获取商品ID
if (!isset($_GET['id']) || !is_numeric($_GET['id'])) {
    die("无效商品ID");
}
$id = (int)$_GET['id'];

// 引入数据库配置文件
require_once '../config.php';

// 数据库连接
$conn = get_db_connection();

// 查询商品信息
$stmt = $conn->prepare("SELECT * FROM products WHERE id = ?");
$stmt->bind_param("i", $id);
$stmt->execute();
$result = $stmt->get_result();
$product = $result->fetch_assoc();

if (!$product) {
    die("商品不存在");
}

// 查询商品单位信息
$unitStmt = $conn->prepare("SELECT * FROM product_units WHERE product_id = ? ORDER BY unit_type DESC");
$unitStmt->bind_param("i", $id);
$unitStmt->execute();
$unitResult = $unitStmt->get_result();
$unitData = [];
$baseUnit = null;

// 先获取基本单位
while ($unit = $unitResult->fetch_assoc()) {
    if ($unit['unit_type'] === 'base') {
        $baseUnit = $unit;
        break;
    }
}

// 重置结果集
$unitResult->data_seek(0);

// 重新处理所有单位数据
while ($unit = $unitResult->fetch_assoc()) {
    // 对于副单位，添加换算比例信息
    if ($unit['unit_type'] === 'sub' && $baseUnit) {
        // 从数据库中的ratio字段获取比例
        // 例如：如果ratio为20，意味着1盒=20支，那么base_ratio=1，sub_ratio=20
        $unit['base_ratio'] = 1; // 基本单位比例默认为1
        $unit['sub_ratio'] = $unit['ratio']; // 副单位比例等于数据库中存储的ratio值
    }
    $unitData[] = $unit;
}

// 查询商品图片
$imageStmt = $conn->prepare("SELECT * FROM product_images WHERE product_id = ? ORDER BY is_main DESC");
$imageStmt->bind_param("i", $id);
$imageStmt->execute();
$imageResult = $imageStmt->get_result();
$imageData = [];
while ($image = $imageResult->fetch_assoc()) {
    $imageData[] = $image;
}

// 确定基本单位和是否为多单位
$isMultiUnit = false;
$baseUnitName = '';
foreach ($unitData as $unit) {
    if ($unit['unit_type'] === 'base') {
        $baseUnitName = $unit['unit_name'];
    }
    if ($unit['unit_type'] === 'sub') {
        $isMultiUnit = true;
    }
}

// 如果没有单位数据，使用商品表中的unit字段
if (empty($baseUnitName) && !empty($product['unit'])) {
    $baseUnitName = $product['unit'];
}

// 查询分类、仓库、供应商
$categories = $conn->query("SELECT id, name FROM categories ORDER BY id");
$warehouses = $conn->query("SELECT id, name FROM warehouses ORDER BY id");
$suppliers = $conn->query("SELECT id, name FROM suppliers ORDER BY id");
?>

<!DOCTYPE html>
<html lang="zh">

<head>
    <meta charset="UTF-8">
    <title>编辑商品</title>
    <link rel="stylesheet" href="style.css">
    <link rel="stylesheet" href="edit_product.css">
</head>

<body>
    <div class="header">
        <h2>编辑商品</h2>
        <a href="list_products.php" class="btn btn-secondary">返回列表</a>
    </div>
    <div class="container">
        <form action="update_product.php" method="post" enctype="multipart/form-data" target="response-frame" id="product-form">
            <input type="hidden" name="id" value="<?= $id ?>">

            <div class="form-group">
                <label>商品编号:</label>
                <input type="text" name="product_code" value="<?= $product['product_code'] ?>">
            </div>

            <div class="form-group">
                <label>商品名称:</label>
                <input type="text" name="product_name" value="<?= $product['product_name'] ?>">
            </div>

            <div class="form-row">
                <div class="form-col">
                    <label>商品类别:</label>
                    <select name="category_id">
                        <option value="">请选择类别</option>
                        <?php while ($row = $categories->fetch_assoc()): ?>
                            <option value="<?= $row['id'] ?>" <?= $row['id'] == $product['category_id'] ? 'selected' : '' ?>><?= htmlspecialchars($row['name']) ?></option>
                        <?php endwhile; ?>
                    </select>
                </div>
                <div class="form-col">
                    <label>商品条码:</label>
                    <input type="text" name="barcode" value="<?= $product['barcode'] ?>">
                </div>
            </div>

            <div class="form-row">
                <div class="form-col">
                    <label>规格型号:</label>
                    <input type="text" name="specification" value="<?= $product['specification'] ?>">
                </div>
                <div class="form-col">
                    <label>首选仓库:</label>
                    <select name="warehouse_id">
                        <option value="">(空)</option>
                        <?php while ($row = $warehouses->fetch_assoc()): ?>
                            <option value="<?= $row['id'] ?>" <?= $row['id'] == $product['warehouse_id'] ? 'selected' : '' ?>><?= htmlspecialchars($row['name']) ?></option>
                        <?php endwhile; ?>
                    </select>
                </div>
            </div>

            <div class="form-row">
                <div class="form-col form-col-checkbox">
                    <label>多单位:</label>
                    <input type="checkbox" name="multi_unit" id="multi_unit_checkbox" value="1" <?= $isMultiUnit ? 'checked' : '' ?>>
                </div>
                <div class="form-col">
                    <label>基本单位:</label>
                    <!-- 基本单位选择框（未勾选多单位时显示） -->
                    <div id="simple_unit_container" style="display: <?= $isMultiUnit ? 'none' : 'block' ?>;">
                        <select name="unit" id="unit_select">
                            <option value="">请选择单位</option>
                            <option value="支" <?= $baseUnitName == '支' ? 'selected' : '' ?>>支</option>
                            <option value="盒" <?= $baseUnitName == '盒' ? 'selected' : '' ?>>盒</option>
                            <option value="箱" <?= $baseUnitName == '箱' ? 'selected' : '' ?>>箱</option>
                        </select>
                    </div>

                    <!-- 多单位输入区域（勾选多单位时显示） -->
                    <div id="multi_unit_container" style="display: <?= $isMultiUnit ? 'block' : 'none' ?>;">
                        <div class="unit-input-display-row">
                            <div class="unit-ratio-input">
                                <input type="text" id="unit_ratio_input" <?= $isMultiUnit ? 'style="display: none;"' : '' ?> placeholder="输入如 1,20 或 1,20,30">
                                <select id="unit_combo_select" style="display: none;">
                                    <option value="">选择单位组合</option>
                                </select>
                                <!-- "请先删除现有单位配比"按钮 -->
                                <button type="button" id="clear-unit-message" class="btn btn-secondary" style="display: <?= $isMultiUnit ? 'inline-block' : 'none' ?>;">请先删除现有单位配比</button>
                            </div>
                            <div id="unit_display" class="unit-display"></div>
                        </div>

                        <div id="unit_ratios_container" class="unit-ratios-container"></div>
                        <!-- 隐藏字段存储单位配比数据 -->
                        <input type="hidden" name="unit_ratios" id="unit_ratios_data">
                    </div>
                </div>
            </div>

            <div class="form-row">
                <div class="form-col">
                    <label>首选入库单位:</label>
                    <select name="preferred_in_unit">
                        <option value="">(空)</option>
                        <option value="支" <?= $product['preferred_in_unit'] == '支' ? 'selected' : '' ?>>支</option>
                        <option value="盒" <?= $product['preferred_in_unit'] == '盒' ? 'selected' : '' ?>>盒</option>
                        <option value="箱" <?= $product['preferred_in_unit'] == '箱' ? 'selected' : '' ?>>箱</option>
                    </select>
                </div>
                <div class="form-col">
                    <label>首选出库单位:</label>
                    <select name="preferred_out_unit">
                        <option value="">(空)</option>
                        <option value="支" <?= $product['preferred_out_unit'] == '支' ? 'selected' : '' ?>>支</option>
                        <option value="盒" <?= $product['preferred_out_unit'] == '盒' ? 'selected' : '' ?>>盒</option>
                        <option value="箱" <?= $product['preferred_out_unit'] == '箱' ? 'selected' : '' ?>>箱</option>
                    </select>
                </div>
            </div>

            <div class="form-row">
                <div class="form-col">
                    <label>产地:</label>
                    <input type="text" name="origin" value="<?= $product['origin'] ?>">
                </div>
                <div class="form-col">
                    <label>注册证号:</label>
                    <input type="text" name="registration_number" value="<?= $product['registration_number'] ?>">
                </div>
            </div>

            <div class="form-row">
                <div class="form-col">
                    <label>品牌:</label>
                    <input type="text" name="brand" value="<?= $product['brand'] ?>">
                </div>
                <div class="form-col">
                    <label>PLU码:</label>
                    <input type="number" name="plu_code" value="<?= $product['plu_code'] ?>">
                </div>
            </div>

            <div class="form-row">
                <div class="form-col">
                    <label>默认供应商:</label>
                    <select name="supplier_id">
                        <option value="">(空)</option>
                        <?php while ($row = $suppliers->fetch_assoc()): ?>
                            <option value="<?= $row['id'] ?>" <?= $row['id'] == $product['supplier_id'] ? 'selected' : '' ?>><?= htmlspecialchars($row['name']) ?></option>
                        <?php endwhile; ?>
                    </select>
                </div>
                <div class="form-col">
                    <label>重量(kg):</label>
                    <input type="number" step="0.01" name="weight" value="<?= $product['weight'] ?>">
                </div>
            </div>

            <div class="form-group">
                <label>尺寸(长宽高):</label>
                <input type="number" step="0.01" name="length" placeholder="长" value="<?= $product['length'] ?>">
                <input type="number" step="0.01" name="width" placeholder="宽" value="<?= $product['width'] ?>">
                <input type="number" step="0.01" name="height" placeholder="高" value="<?= $product['height'] ?>">
                <select disabled>
                    <option>cm</option>
                </select>
            </div>

            <h3>价格策略</h3>

            <div class="form-group form-col-checkbox">
                <label>价格策略:</label>
                <input type="checkbox" name="price_strategy_enabled" value="1" id="price_strategy_enabled" <?= $product['price_strategy_enabled'] ? 'checked' : '' ?>> 启用
            </div>

            <div id="price-strategy-container">
                <table class="multi-unit-table" id="price-strategy-table">
                    <thead>
                        <tr>
                            <th>类型</th>
                            <th>计量单位</th>
                            <th>换算公式</th>
                            <th>包装条码</th>
                            <th>零售价</th>
                            <th>批发价</th>
                            <th>VIP会员价</th>
                            <th>折扣率1(%)</th>
                            <th>折扣率2(%)</th>
                        </tr>
                    </thead>
                    <tbody>
                        <tr id="base-unit-row">
                            <td>基本单位</td>
                            <td id="base-unit-cell"><?= $baseUnitName ?></td>
                            <td>1<span id="base-unit-name"><?= $baseUnitName ?></span></td>
                            <td><input type="text" name="barcode" value="<?= $product['barcode'] ?>"></td>
                            <td><input type="number" step="0.01" name="retail_price" value="<?= $product['retail_price'] ?>"></td>
                            <td><input type="number" step="0.01" name="wholesale_price" value="<?= $product['wholesale_price'] ?>"></td>
                            <td><input type="number" step="0.01" name="vip_price" value="<?= $product['vip_price'] ?>"></td>
                            <td><input type="number" step="0.01" name="discount1" value="<?= $product['discount1'] ?>" class="unit-discount" data-base-discount-field="discount1"></td>
                            <td><input type="number" step="0.01" name="discount2" value="<?= $product['discount2'] ?>" class="unit-discount" data-base-discount-field="discount2"></td>
                        </tr>
                        <!-- 副单位行将由JavaScript动态生成 -->
                    </tbody>
                </table>
            </div>

            <div class="form-row">
                <div class="form-col">
                    <label>最低销售价:</label>
                    <input type="number" step="0.01" name="min_sale_price" value="<?= $product['min_sale_price'] ?>">
                </div>
                <div class="form-col">
                    <label>预计采购价:</label>
                    <input type="number" step="0.01" name="estimated_purchase_price" value="<?= $product['estimated_purchase_price'] ?>">
                </div>
                <div class="form-col">
                    <label>最高采购价:</label>
                    <input type="number" step="0.01" name="max_purchase_price" value="<?= $product['max_purchase_price'] ?>">
                </div>
            </div>

            <h3>开发票信息</h3>

            <div class="form-row">
                <div class="form-col">
                    <label>商品税率(%):</label>
                    <input type="number" step="0.01" name="tax_rate" value="<?= $product['tax_rate'] ?>">
                </div>
                <div class="form-col">
                    <label>税收分类编码:</label>
                    <input type="text" name="tax_code" value="<?= $product['tax_code'] ?>">
                </div>
            </div>

            <div class="form-row">
                <div class="form-col">
                    <label>是否免税:</label>
                    <select name="is_tax_exempt">
                        <option value="0" <?= $product['is_tax_exempt'] == 0 ? 'selected' : '' ?>>否</option>
                        <option value="1" <?= $product['is_tax_exempt'] == 1 ? 'selected' : '' ?>>是</option>
                    </select>
                </div>
                <div class="form-col">
                    <label>商品开票名称:</label>
                    <input type="text" name="invoice_name" value="<?= $product['invoice_name'] ?>">
                </div>
            </div>

            <h3>备注</h3>

            <div class="form-group">
                <label>备注信息:</label>
                <textarea name="remarks"><?= $product['remarks'] ?></textarea>
            </div>
            <h3>商品图片</h3>
            <div class="form-group">
                <label>上传商品图片:</label>
                <input type="file" name="product_images[]" multiple accept="image/*" id="product-images">
                <small>最多上传 20 张图片，支持 JPG/PNG/JPEG 格式</small>
            </div>

            <!-- 添加图片预览区域 -->
            <div class="image-preview">
                <div class="image-grid" id="image-preview-container">
                    <?php if (!empty($imageData)): ?>
                        <div class="current-images">
                            <?php foreach ($imageData as $index => $image): ?>
                                <div class="image-item" id="image-item-<?= $image['id'] ?>">
                                    <img src="<?= $image['file_path'] ?>" class="preview-image" alt="商品图片">
                                    <?php if ($image['is_main']): ?>
                                        <span class="main-label">主图</span>
                                    <?php endif; ?>
                                    <button type="button" class="delete-image" data-image-id="<?= $image['id'] ?>" title="删除图片">×</button>
                                </div>
                            <?php endforeach; ?>
                        </div>
                    <?php endif; ?>
                </div>
            </div>

            <!-- 添加隐藏字段，用于存储已删除的图片索引 -->
            <input type="hidden" name="deleted_image_indexes" id="deleted-image-indexes" value="">

            <div class="btn-group">
                <button type="reset" class="btn btn-secondary">清空</button>
                <button type="submit" class="btn">保存</button>
            </div>
        </form>
    </div>

    <!-- 添加消息显示区域 -->
    <div id="message-container"></div>

    <!-- 隐藏的iframe用于接收表单提交响应 -->
    <iframe name="response-frame" id="response-frame" style="display:none;"></iframe>

    <!-- 数据传递给JavaScript -->
    <script>
        // 将PHP数据转换为JavaScript变量
        window.productUnitData = <?= json_encode($unitData) ?>;

        // 消息显示函数
        function showMessage(message, type = 'success') {
            const messageContainer = document.getElementById('message-container');
            messageContainer.innerHTML = `
                <div class="message">
                    <span>${message}</span>
                    <button onclick="this.parentElement.remove()">×</button>
                </div>
            `;

            // 3秒后自动消失
            setTimeout(() => {
                const messageElement = messageContainer.querySelector('.message');
                if (messageElement) {
                    messageElement.remove();
                }
            }, 3000);
        }

        // 页面加载完成后初始化
        document.addEventListener('DOMContentLoaded', function() {
            initMultiUnitInput();
            initUnitAutoFill();
            initImageHandlers();

            // 加载现有单位数据
            if (typeof window.loadExistingUnitRatios === 'function' && window.productUnitData) {
                window.loadExistingUnitRatios(window.productUnitData);
            }

            // 如果有错误或消息需要显示，处理这些信息
            const urlParams = new URLSearchParams(window.location.search);
            if (urlParams.has('message')) {
                showMessage(decodeURIComponent(urlParams.get('message')));
            }

            // 监听隐藏iframe的加载事件，处理表单提交后的响应
            document.getElementById('response-frame').onload = function() {
                try {
                    var response = this.contentWindow.document.body.innerHTML;
                    if (response && response.includes('✅')) {
                        // 添加refresh=1参数强制刷新列表页缓存
                        window.location.href = 'list_products.php?message=更新成功&refresh=1';
                    } else if (response && response.includes('❌')) {
                        const errorMessage = response.replace('❌ 错误: ', '');
                        showMessage('保存失败: ' + errorMessage);
                    }
                } catch (e) {
                    // 可能出现跨域错误，忽略
                }
            };
        });

        // 多单位管理模块
        function initMultiUnitInput() {
            const multiUnitCheckbox = document.getElementById('multi_unit_checkbox');
            const simpleUnitContainer = document.getElementById('simple_unit_container');
            const multiUnitContainer = document.getElementById('multi_unit_container');
            const unitSelect = document.getElementById('unit_select');
            const unitRatioInput = document.getElementById('unit_ratio_input');
            const unitComboSelect = document.getElementById('unit_combo_select');
            const unitDisplay = document.getElementById('unit_display');
            const unitRatiosContainer = document.getElementById('unit_ratios_container');
            const unitRatiosData = document.getElementById('unit_ratios_data');
            const baseUnitCell = document.getElementById('base-unit-cell');
            const baseUnitName = document.getElementById('base-unit-name');
            const priceStrategyTable = document.getElementById('price-strategy-table');
            let unitRatios = [];

            function getAllUnits() {
                const units = [];
                for (let i = 0; i < unitSelect.options.length; i++) {
                    if (unitSelect.options[i].value) units.push(unitSelect.options[i].value);
                }
                return units;
            }

            multiUnitCheckbox.addEventListener('change', function() {
                if (this.checked) {
                    simpleUnitContainer.style.display = 'none';
                    multiUnitContainer.style.display = 'block';
                    if (unitSelect.value) {
                        unitDisplay.textContent = unitSelect.value;
                        updatePriceStrategyTable(unitSelect.value);
                    }
                    unitRatioInput.disabled = false;
                    unitRatioInput.placeholder = "输入如 1,20 或 1,20,30";
                    unitRatioInput.style.display = "block";
                    document.getElementById('clear-unit-message').style.display = 'none';
                } else {
                    simpleUnitContainer.style.display = 'block';
                    multiUnitContainer.style.display = 'none';
                    unitRatios = [];
                    unitRatiosContainer.innerHTML = '';
                    unitRatiosData.value = '';
                    unitDisplay.textContent = '';
                    updatePriceStrategyTable(unitSelect.value);
                    removeAllSubUnitRows();
                    unitRatioInput.disabled = false;
                    unitRatioInput.placeholder = "输入如 1,20 或 1,20,30";
                    unitRatioInput.style.display = "block";
                    document.getElementById('clear-unit-message').style.display = 'none';
                }
            });

            unitRatioInput.addEventListener('input', function() {
                const value = this.value.trim();
                const ratioPattern = /^\d+(,\d+)+$/;
                if (ratioPattern.test(value)) {
                    generateUnitCombinations();
                    unitComboSelect.style.display = 'block';
                } else {
                    unitComboSelect.style.display = 'none';
                }
            });

            function generateUnitCombinations() {
                const units = getAllUnits();
                unitComboSelect.innerHTML = '<option value="">选择单位组合</option>';
                const values = unitRatioInput.value.trim().split(',');

                if (values.length === 2) {
                    for (let i = 0; i < units.length; i++) {
                        for (let j = 0; j < units.length; j++) {
                            if (i !== j) {
                                const option = document.createElement('option');
                                option.value = `${units[i]},${units[j]}`;
                                option.textContent = `${units[i]},${units[j]}`;
                                unitComboSelect.appendChild(option);
                            }
                        }
                    }
                } else if (values.length === 3) {
                    const standardOrder = ["支", "盒", "箱"];
                    if (standardOrder.every(unit => units.includes(unit))) {
                        const standardOption = document.createElement('option');
                        standardOption.value = standardOrder.join(',');
                        standardOption.textContent = `${standardOrder.join(',')} (标准)`;
                        unitComboSelect.appendChild(standardOption);
                    }

                    // 生成所有可能的三单位组合（包括自定义顺序）
                    for (let i = 0; i < units.length; i++) {
                        for (let j = 0; j < units.length; j++) {
                            for (let k = 0; k < units.length; k++) {
                                if (i !== j && i !== k && j !== k) {
                                    const comboValue = `${units[i]},${units[j]},${units[k]}`;
                                    // 避免重复添加标准组合
                                    if (comboValue !== standardOrder.join(',')) {
                                        const option = document.createElement('option');
                                        option.value = comboValue;
                                        option.textContent = comboValue;
                                        unitComboSelect.appendChild(option);
                                    }
                                }
                            }
                        }
                    }
                }
            }

            unitComboSelect.addEventListener('change', function() {
                const unitCombo = this.value;
                if (!unitCombo) return;

                const ratioValue = unitRatioInput.value.trim();
                if (!ratioValue) return;

                const ratioNumbers = ratioValue.split(',').map(n => parseInt(n));
                const units = unitCombo.split(',');

                // 记录用户选择的单位组合顺序
                console.log('用户选择的单位组合:', unitCombo);
                console.log('用户输入的比例:', ratioValue);

                if (units.length === 2 && ratioNumbers.length === 2) {
                    // 按用户选择的顺序添加
                    addUnitRatio(units[0], units[1], ratioNumbers[0], ratioNumbers[1]);
                } else if (units.length === 3 && ratioNumbers.length === 3) {
                    // 对于三单位组合，将其理解为递进关系
                    // 假设用户输入1,20,30，选择支,盒,箱时:
                    // 应该理解为1支=1支，1盒=20支，1箱=30盒=600支

                    const unit1 = units[0]; // 基本单位（如"支"）
                    const unit2 = units[1]; // 中间单位（如"盒"）
                    const unit3 = units[2]; // 最大单位（如"箱"）

                    const ratio1 = ratioNumbers[0]; // 基本单位比例（通常为1）
                    const ratio2 = ratioNumbers[1]; // 中间单位与基本单位的比例（如20，表示1盒=20支）
                    const ratio3 = ratioNumbers[2]; // 最大单位与中间单位的比例（如30，表示1箱=30盒）

                    // 计算最大单位与基本单位的关系（如1箱=30盒=30*20支=600支）
                    const combinedRatio = ratio2 * ratio3;

                    console.log(`基本单位关系: 1${unit2}=${ratio2}${unit1}, 1${unit3}=${ratio3}${unit2}, 1${unit3}=${combinedRatio}${unit1}`);

                    // 添加基本单位与中间单位的关系
                    addUnitRatio(unit1, unit2, ratio1, ratio2);

                    // 添加基本单位与最大单位的关系
                    addUnitRatio(unit1, unit3, ratio1, combinedRatio);

                    // 我们也可以添加中间单位与最大单位的关系，虽然目前不需要
                    // addUnitRatio(unit2, unit3, 1, ratio3);
                }

                unitRatioInput.value = '';
                unitComboSelect.value = '';
                unitComboSelect.style.display = 'none';
            });

            function addUnitRatio(unit1, unit2, num1, num2) {
                const newRatio = {
                    unit1,
                    unit2,
                    num1,
                    num2
                };
                unitRatios.push(newRatio);
                findBaseUnitAndUpdateRatios();
                updateUnitRatiosData();
                updateUnitRatiosList();
                unitRatioInput.disabled = true;
                unitRatioInput.style.display = "none";
                document.getElementById('clear-unit-message').style.display = 'inline-block';
            }

            function deleteUnitRatio(index) {
                if (index === undefined) {
                    // 删除全部
                    unitRatios = [];
                    unitDisplay.textContent = '';
                    unitSelect.value = '';
                    updatePriceStrategyTable('');
                } else {
                    // 删除指定索引
                    unitRatios.splice(index, 1);
                    if (unitRatios.length > 0) {
                        findBaseUnitAndUpdateRatios();
                    } else {
                        unitDisplay.textContent = '';
                        unitSelect.value = '';
                        updatePriceStrategyTable('');
                    }
                }

                updateUnitRatiosData();
                updateUnitRatiosList();

                if (unitRatios.length === 0) {
                    unitRatioInput.disabled = false;
                    unitRatioInput.style.display = "block";
                    unitRatioInput.placeholder = "输入如 1,20 或 1,20,30";
                    document.getElementById('clear-unit-message').style.display = 'none';
                }
            }

            function findBaseUnitAndUpdateRatios() {
                if (unitRatios.length === 0) return;

                // 分析所有单位比例，找出基本单位
                let unitCounts = {};
                unitRatios.forEach(ratio => {
                    unitCounts[ratio.unit1] = (unitCounts[ratio.unit1] || 0) + 1;
                    unitCounts[ratio.unit2] = (unitCounts[ratio.unit2] || 0) + 1;
                });

                // 假设出现最多的单位是基本单位
                let baseUnit = Object.keys(unitCounts).reduce((a, b) => unitCounts[a] > unitCounts[b] ? a : b);

                // 优先选择单位1作为基本单位
                const firstRatio = unitRatios[0];
                baseUnit = firstRatio.unit1;

                unitSelect.value = baseUnit;
                unitDisplay.textContent = baseUnit;
                updatePriceStrategyTable(baseUnit);
            }

            function updateUnitRatiosData() {
                const baseUnit = unitSelect.value;
                const apiData = [];

                if (baseUnit && unitRatios.length > 0) {
                    unitRatios.forEach(ratio => {
                        if (ratio.unit1 === baseUnit) {
                            apiData.push({
                                baseUnit: baseUnit,
                                subUnit: ratio.unit2,
                                ratio1: ratio.num1,
                                ratio2: ratio.num2
                            });
                        } else if (ratio.unit2 === baseUnit) {
                            apiData.push({
                                baseUnit: baseUnit,
                                subUnit: ratio.unit1,
                                ratio1: ratio.num2,
                                ratio2: ratio.num1
                            });
                        }
                    });
                }
                unitRatiosData.value = JSON.stringify(apiData);
            }

            function updateUnitRatiosDisplay() {
                // 更新单位显示区
                unitDisplay.textContent = unitSelect.value || '';
            }

            function updateUnitRatiosList() {
                unitRatiosContainer.innerHTML = '';
                const baseUnit = unitSelect.value;
                removeAllSubUnitRows();
                updateUnitRatiosDisplay();

                if (!baseUnit || unitRatios.length === 0) return;

                const threeUnitRelationship = findThreeUnitRelationship();

                if (threeUnitRelationship) {
                    displayThreeUnitRelationship(threeUnitRelationship);
                } else {
                    unitRatios.forEach((ratio, index) => {
                        displayTwoUnitRelationship(ratio, index);
                    });
                }
            }

            function findThreeUnitRelationship() {
                if (unitRatios.length < 2) return null;

                // 优先处理标准单位组合（支、盒、箱）
                const standardUnits = ['支', '盒', '箱'];
                const baseUnit = unitSelect.value;

                // 查找所有单位名称
                const unitSet = new Set();
                unitRatios.forEach(ratio => {
                    unitSet.add(ratio.unit1);
                    unitSet.add(ratio.unit2);
                });
                const units = Array.from(unitSet);

                // 验证是否有三单位组合
                if (units.length >= 3) {
                    // 记录用户的选择顺序
                    const userSelectedOrder = [];
                    unitRatios.forEach(ratio => {
                        if (ratio.unit1 === baseUnit) {
                            userSelectedOrder.push(ratio.unit2);
                        } else if (ratio.unit2 === baseUnit) {
                            userSelectedOrder.push(ratio.unit1);
                        }
                    });

                    console.log('用户选择的单位顺序:', userSelectedOrder);

                    // 是否为标准单位组合
                    const isStandardCombination = standardUnits.every(unit =>
                        unit === baseUnit || userSelectedOrder.includes(unit)
                    );

                    console.log('是否为标准单位组合:', isStandardCombination);

                    // 找出基本单位和其他单位的关系
                    const ratioData = {};
                    userSelectedOrder.forEach(unit => {
                        ratioData[unit] = {
                            ratio: 0
                        };
                    });

                    // 收集所有单位比例数据
                    unitRatios.forEach(ratio => {
                        if (ratio.unit1 === baseUnit && ratioData[ratio.unit2]) {
                            ratioData[ratio.unit2].ratio = ratio.num2 / ratio.num1;
                            ratioData[ratio.unit2].num1 = ratio.num1;
                            ratioData[ratio.unit2].num2 = ratio.num2;
                        } else if (ratio.unit2 === baseUnit && ratioData[ratio.unit1]) {
                            ratioData[ratio.unit1].ratio = ratio.num1 / ratio.num2;
                            ratioData[ratio.unit1].num1 = ratio.num2;
                            ratioData[ratio.unit1].num2 = ratio.num1;
                        }
                    });

                    console.log('三单位关系数据：', ratioData);

                    // 按照用户选择的顺序提取单位
                    if (userSelectedOrder.length >= 2) {
                        // 按照用户选择的顺序返回结果
                        const smallUnit = userSelectedOrder[0]; // 第一个副单位
                        const midUnit = userSelectedOrder[1]; // 第二个副单位

                        const smallData = ratioData[smallUnit];
                        const midData = ratioData[midUnit];

                        if (smallData && midData && smallData.ratio > 0 && midData.ratio > 0) {
                            return {
                                baseUnit,
                                midUnit,
                                smallUnit,
                                ratio1: 1, // 基本单位比例固定为1
                                ratio2: midData.num2, // 中间单位的比例
                                ratio3: smallData.num2 // 最小单位的比例
                            };
                        }
                    }
                }

                // 如果没有找到三单位关系，使用旧的逻辑
                // 先尝试通过unitRatios直接构建
                if (unitRatios.length >= 2) {
                    const related = unitRatios.filter(ratio =>
                        ratio.unit1 === baseUnit || ratio.unit2 === baseUnit
                    );

                    if (related.length >= 2) {
                        const subUnits = [];
                        const subRatios = {};

                        related.forEach(ratio => {
                            let subUnit, subRatio;
                            if (ratio.unit1 === baseUnit) {
                                subUnit = ratio.unit2;
                                subRatio = ratio.num2;
                            } else {
                                subUnit = ratio.unit1;
                                subRatio = ratio.num1;
                            }
                            subUnits.push(subUnit);
                            subRatios[subUnit] = subRatio;
                        });

                        if (subUnits.length >= 2) {
                            return {
                                baseUnit,
                                midUnit: subUnits[0],
                                smallUnit: subUnits[1],
                                ratio1: 1,
                                ratio2: subRatios[subUnits[0]],
                                ratio3: subRatios[subUnits[1]]
                            };
                        }
                    }
                }

                // 使用链式关系构建
                const unitChain = buildUnitChain(unitRatios);
                if (unitChain.length < 3) return null;

                const relatedUnits = unitChain.filter(unit => unit !== baseUnit);
                if (relatedUnits.length < 2) return null;

                // 找出直接与基本单位相关的两个单位
                const midUnit = relatedUnits[0];
                const smallUnit = relatedUnits[1];

                // 计算比例
                let ratio1, ratio2, ratio3;

                unitRatios.forEach(ratio => {
                    if (ratio.unit1 === baseUnit && ratio.unit2 === midUnit) {
                        ratio1 = ratio.num1;
                        ratio2 = ratio.num2;
                    } else if (ratio.unit1 === midUnit && ratio.unit2 === baseUnit) {
                        ratio1 = ratio.num2;
                        ratio2 = ratio.num1;
                    }

                    if (ratio.unit1 === baseUnit && ratio.unit2 === smallUnit) {
                        ratio3 = ratio.num2;
                    } else if (ratio.unit1 === smallUnit && ratio.unit2 === baseUnit) {
                        ratio3 = ratio.num1;
                    }
                });

                if (!ratio1 || !ratio2 || !ratio3) return null;

                return {
                    baseUnit,
                    midUnit,
                    smallUnit,
                    ratio1,
                    ratio2,
                    ratio3
                };
            }

            // 构建单位链，从最小单位到最大单位
            function buildUnitChain(ratios) {
                if (!ratios || ratios.length === 0) return [];

                // 特殊处理支、盒、箱的标准关系
                const standardUnits = ['支', '盒', '箱'];
                const unitsInRatios = new Set();
                ratios.forEach(ratio => {
                    unitsInRatios.add(ratio.unit1);
                    unitsInRatios.add(ratio.unit2);
                });

                // 检查是否包含标准单位
                const hasAllStandardUnits = standardUnits.every(unit => unitsInRatios.has(unit));
                if (hasAllStandardUnits) {
                    // 直接返回标准单位链
                    return standardUnits;
                }

                // 收集所有单位
                const units = new Set();
                ratios.forEach(ratio => {
                    units.add(ratio.unit1);
                    units.add(ratio.unit2);
                });

                // 如果只有一个单位，直接返回
                if (units.size <= 1) return Array.from(units);

                // 构建单位关系图
                const graph = {};
                units.forEach(unit => {
                    graph[unit] = [];
                });

                ratios.forEach(ratio => {
                    graph[ratio.unit1].push({
                        unit: ratio.unit2,
                        ratio: ratio.num2 / ratio.num1
                    });

                    graph[ratio.unit2].push({
                        unit: ratio.unit1,
                        ratio: ratio.num1 / ratio.num2
                    });
                });

                // 尝试查找单位链
                const baseUnit = ratios[0].unit1;
                const visited = new Set([baseUnit]);
                const chain = [baseUnit];

                // 递归查找链
                function findChain(current) {
                    const neighbors = graph[current];

                    // 按比例从小到大排序
                    neighbors.sort((a, b) => a.ratio - b.ratio);

                    for (const neighbor of neighbors) {
                        if (!visited.has(neighbor.unit)) {
                            visited.add(neighbor.unit);
                            chain.push(neighbor.unit);
                            findChain(neighbor.unit);
                            break;
                        }
                    }
                }

                findChain(baseUnit);
                return chain;
            }

            function displayThreeUnitRelationship(relation) {
                const {
                    baseUnit,
                    midUnit,
                    smallUnit,
                    ratio1,
                    ratio2,
                    ratio3
                } = relation;

                console.log('显示三单位关系详细信息：', {
                    baseUnit,
                    midUnit,
                    smallUnit,
                    ratio1,
                    ratio2,
                    ratio3,
                    'midUnit/baseUnit': ratio2 / ratio1,
                    'smallUnit/baseUnit': ratio3 / ratio1,
                    'smallUnit/midUnit': ratio3 / ratio2
                });

                const ratioItem = document.createElement('div');
                ratioItem.className = 'unit-ratio-item';

                // 创建单位映射
                const unitMap = {
                    [baseUnit]: ratio1,
                    [midUnit]: ratio2,
                    [smallUnit]: ratio3
                };

                // 尊重原始的单位顺序
                let displayUnits = [];
                let displayRatios = [];

                // 标准单位组合
                const standardUnits = ["支", "盒", "箱"];
                const isStandardCombination = [baseUnit, midUnit, smallUnit].every(unit => standardUnits.includes(unit));

                // 检查用户是否已经通过选择单位组合手动设置了顺序
                const userSelectedOrder = unitRatios.map(ratio =>
                    ratio.unit1 === baseUnit ? ratio.unit2 : ratio.unit2 === baseUnit ? ratio.unit1 : null
                ).filter(Boolean);

                // 使用用户选择的单位顺序（如果存在）
                if (userSelectedOrder.length >= 2) {
                    console.log('使用用户选择的单位顺序:', userSelectedOrder);

                    // 确保基本单位在第一位
                    displayUnits = [baseUnit, ...userSelectedOrder];
                    // 去重
                    displayUnits = [...new Set(displayUnits)];
                    // 确保只有我们需要的三个单位
                    displayUnits = displayUnits.filter(unit =>
                        unit === baseUnit || unit === midUnit || unit === smallUnit
                    );

                    // 对应的比例值
                    displayRatios = displayUnits.map(unit => unitMap[unit]);

                    // 检查是否为"支,盒,箱"标准组合
                    if (isStandardCombination) {
                        console.log('检测到标准单位组合');

                        // 计算比例关系是否符合递进关系
                        if (ratio3 > ratio2 && ratio3 % ratio2 === 0) {
                            const recursiveRatio = ratio3 / ratio2;
                            console.log(`检测到递进关系: 1${smallUnit}=${recursiveRatio}${midUnit}=${ratio3}${baseUnit}`);

                            // 可以选择在显示中添加递进关系的说明，如 "支,盒,箱(1:20:600) [1盒=20支,1箱=30盒]"
                        }
                    }
                } else {
                    // 如果没有用户选择的顺序，则使用三单位关系中的顺序
                    displayUnits = [baseUnit, midUnit, smallUnit];
                    displayRatios = [ratio1, ratio2, ratio3];
                }

                const ratioText = `${displayUnits.join(',')}(${displayRatios.join(':')})`;

                const ratioSpan = document.createElement('span');
                ratioSpan.innerHTML = ratioText;

                const deleteBtn = document.createElement('button');
                deleteBtn.type = 'button';
                deleteBtn.className = 'delete-ratio';
                deleteBtn.innerHTML = '×';
                deleteBtn.title = '删除此配比';

                deleteBtn.addEventListener('click', function() {
                    deleteUnitRatio();
                });

                ratioItem.appendChild(ratioSpan);
                ratioItem.appendChild(deleteBtn);
                unitRatiosContainer.appendChild(ratioItem);

                // 从显示的单位顺序中移除基本单位，只保留副单位
                const subUnits = displayUnits.filter(unit => unit !== baseUnit);
                const subRatios = [];

                // 根据单位获取正确的比例关系
                subUnits.forEach(unit => {
                    if (unit === midUnit) {
                        subRatios.push({
                            unit: unit,
                            ratio: ratio2
                        });
                    } else if (unit === smallUnit) {
                        subRatios.push({
                            unit: unit,
                            ratio: ratio3
                        });
                    }
                });

                // 按顺序添加副单位行
                subRatios.forEach((data, index) => {
                    addSubUnitRow(data.unit, ratio1, data.ratio, baseUnit, index);
                });

                console.log('副单位顺序：', subUnits);
                console.log('副单位比例：', subRatios.map(r => r.ratio));
            }

            function displayTwoUnitRelationship(ratio, index) {
                const ratioItem = document.createElement('div');
                ratioItem.className = 'unit-ratio-item';
                let ratioText, subUnit, num1, num2;
                const baseUnit = unitSelect.value;

                if (ratio.unit1 === baseUnit) {
                    ratioText = `${ratio.unit1},${ratio.unit2}(${ratio.num1}:${ratio.num2})`;
                    subUnit = ratio.unit2;
                    num1 = ratio.num1;
                    num2 = ratio.num2;
                } else if (ratio.unit2 === baseUnit) {
                    ratioText = `${ratio.unit2},${ratio.unit1}(${ratio.num2}:${ratio.num1})`;
                    subUnit = ratio.unit1;
                    num1 = ratio.num2;
                    num2 = ratio.num1;
                } else {
                    ratioText = `${ratio.unit2},${ratio.unit1}(${ratio.num1}:${ratio.num2})`;
                    subUnit = ratio.unit2;
                    num1 = ratio.num1;
                    num2 = ratio.num2;
                }

                const ratioSpan = document.createElement('span');
                ratioSpan.innerHTML = ratioText;
                const deleteBtn = document.createElement('button');
                deleteBtn.type = 'button';
                deleteBtn.className = 'delete-ratio';
                deleteBtn.innerHTML = '×';
                deleteBtn.title = '删除此配比';
                deleteBtn.dataset.index = index;

                deleteBtn.addEventListener('click', function() {
                    const idx = parseInt(this.dataset.index);
                    deleteUnitRatio(idx);
                });

                ratioItem.appendChild(ratioSpan);
                ratioItem.appendChild(deleteBtn);
                unitRatiosContainer.appendChild(ratioItem);
                addSubUnitRow(subUnit, num1, num2, baseUnit, index);
            }

            function updatePriceStrategyTable(baseUnit) {
                if (!baseUnit) baseUnit = '';
                baseUnitCell.textContent = baseUnit;
                baseUnitName.textContent = baseUnit;
            }

            function addSubUnitRow(subUnit, num1, num2, baseUnit, index) {
                const trId = `sub-unit-row-${index}`;
                let row = document.getElementById(trId);
                if (!row) {
                    row = document.createElement('tr');
                    row.id = trId;
                    priceStrategyTable.querySelector('tbody').appendChild(row);
                }

                // 从product_units表中获取副单位数据
                let subUnitBarcode = '';
                let subRetailPrice = '';
                let subWholesalePrice = '';
                let subVipPrice = '';

                if (window.productUnitData) {
                    window.productUnitData.forEach(unit => {
                        if (unit.unit_name === subUnit && unit.unit_type === 'sub') {
                            subUnitBarcode = unit.barcode || '';
                            subRetailPrice = unit.retail_price || '';
                            subWholesalePrice = unit.wholesale_price || '';
                            subVipPrice = unit.vip_price || '';
                        }
                    });
                }

                row.innerHTML = `
                    <td>副单位${index + 1}</td>
                    <td>${subUnit}</td>
                    <td>1${subUnit}=${num2}${baseUnit}</td>
                    <td><input type="text" name="sub_barcode_${index}" value="${subUnitBarcode}"></td>
                    <td><input type="number" step="0.01" name="sub_retail_price_${index}" class="unit-price" data-ratio="${num2}" data-base-price-field="retail_price" value="${subRetailPrice}"></td>
                    <td><input type="number" step="0.01" name="sub_wholesale_price_${index}" class="unit-price" data-ratio="${num2}" data-base-price-field="wholesale_price" value="${subWholesalePrice}"></td>
                    <td><input type="number" step="0.01" name="sub_vip_price_${index}" class="unit-price" data-ratio="${num2}" data-base-price-field="vip_price" value="${subVipPrice}"></td>
                    <td><input type="number" step="0.01" name="sub_discount1_${index}" value="${document.querySelector('input[name="discount1"]').value || 0}" class="unit-discount" data-base-discount-field="discount1"></td>
                    <td><input type="number" step="0.01" name="sub_discount2_${index}" value="${document.querySelector('input[name="discount2"]').value || 0}" class="unit-discount" data-base-discount-field="discount2"></td>
                `;

                attachUnitPriceHandlers(row);
                attachDiscountHandlers(row);
            }

            function removeAllSubUnitRows() {
                const tbody = priceStrategyTable.querySelector('tbody');
                const rows = tbody.querySelectorAll('tr[id^="sub-unit-row-"]');
                rows.forEach(row => row.remove());
            }

            function attachUnitPriceHandlers(row) {
                const inputs = row.querySelectorAll('.unit-price');
                inputs.forEach(input => {
                    const baseField = input.dataset.basePriceField;
                    const ratio = parseFloat(input.dataset.ratio);
                    const baseInput = document.querySelector(`input[name="${baseField}"]`);

                    if (baseInput) {
                        baseInput.addEventListener('input', function() {
                            if (this.value) {
                                const basePrice = parseFloat(this.value);
                                input.value = (basePrice * ratio).toFixed(2);
                            }
                        });

                        if (baseInput.value && !input.value) {
                            const basePrice = parseFloat(baseInput.value);
                            input.value = (basePrice * ratio).toFixed(2);
                        }

                        input.addEventListener('input', function() {
                            if (this.value) {
                                const subPrice = parseFloat(this.value);
                                baseInput.value = (subPrice / ratio).toFixed(2);
                            }
                        });
                    }
                });
            }

            function attachDiscountHandlers(row) {
                const discountInputs = row.querySelectorAll('.unit-discount');
                discountInputs.forEach(input => {
                    const baseDiscountField = input.dataset.baseDiscountField;
                    const baseDiscountInput = document.querySelector(`input[name="${baseDiscountField}"]`);

                    if (baseDiscountInput) {
                        baseDiscountInput.addEventListener('input', function() {
                            input.value = this.value;
                        });

                        input.addEventListener('input', function() {
                            baseDiscountInput.value = this.value;
                            document.querySelectorAll(`input[data-base-discount-field="${baseDiscountField}"]`)
                                .forEach(el => {
                                    if (el !== input) el.value = this.value;
                                });
                        });
                    }
                });
            }

            // 从API中加载现有单位比例数据
            window.loadExistingUnitRatios = function(unitData) {
                if (!unitData || unitData.length === 0) return;

                console.log('加载现有单位数据:', unitData);

                // 找出基本单位
                let baseUnitData = unitData.find(unit => unit.unit_type === 'base');
                if (!baseUnitData) return;

                const baseUnit = baseUnitData.unit_name;
                unitSelect.value = baseUnit;
                updatePriceStrategyTable(baseUnit);

                // 处理单位比例
                let subUnitData = unitData.filter(unit => unit.unit_type === 'sub');
                if (subUnitData.length === 0) return;

                // 先清空任何可能存在的单位比例
                unitRatios = [];

                // 优先处理标准单位组合（支、盒、箱）
                const standardUnits = ['支', '盒', '箱'];
                const unitNames = subUnitData.map(unit => unit.unit_name);

                console.log('副单位名称:', unitNames);
                console.log('是否包含标准单位组合:', standardUnits.every(unit => unit === baseUnit || unitNames.includes(unit)));

                // 检查是否存在标准单位组合
                const hasStandardUnits = standardUnits.every(unit =>
                    unit === baseUnit || unitNames.includes(unit)
                );

                // 有序的单位数据
                let orderedSubUnitData = [...subUnitData];

                // 如果使用标准单位组合则按标准顺序排序
                if (hasStandardUnits) {
                    console.log('使用标准单位组合处理');
                    const standardMap = {};
                    standardUnits.forEach((unit, index) => {
                        standardMap[unit] = index;
                    });

                    orderedSubUnitData.sort((a, b) => {
                        const indexA = standardMap[a.unit_name] || 999;
                        const indexB = standardMap[b.unit_name] || 999;
                        return indexA - indexB;
                    });

                    console.log('排序后的副单位数据:', orderedSubUnitData.map(unit => unit.unit_name));
                }

                // 分析单位之间的关系结构
                if (orderedSubUnitData.length >= 2) {
                    // 获取所有副单位的比例
                    const ratios = {};
                    const units = [baseUnit];

                    orderedSubUnitData.forEach(subUnit => {
                        const unitName = subUnit.unit_name;
                        const ratio = parseInt(subUnit.ratio) || 1;
                        ratios[unitName] = ratio;
                        units.push(unitName);
                    });

                    console.log('单位列表:', units);
                    console.log('单位比例:', ratios);

                    // 解析单位间的递进关系（如果存在）
                    if (units.length === 3) {
                        // 基本单位、中间单位、最大单位
                        const unit1 = units[0]; // 基本单位
                        const unit2 = units[1]; // 中间单位
                        const unit3 = units[2]; // 最大单位

                        const ratio2 = ratios[unit2]; // 中间单位比例
                        const ratio3 = ratios[unit3]; // 最大单位比例

                        if (hasStandardUnits && standardUnits.includes(unit2) && standardUnits.includes(unit3)) {
                            // 对于标准单位（支、盒、箱），尝试检测是否存在递进关系
                            // 例如: 1盒=20支，1箱=600支，那么可能意味着1箱=30盒
                            if (ratio3 > ratio2 && ratio3 % ratio2 === 0) {
                                const recursiveRatio = ratio3 / ratio2;
                                console.log(`检测到递进关系: 1${unit3}=${recursiveRatio}${unit2}`);

                                // 添加基本单位与中间单位的关系
                                unitRatios.push({
                                    unit1: unit1,
                                    unit2: unit2,
                                    num1: 1,
                                    num2: ratio2
                                });

                                // 添加基本单位与最大单位的关系
                                unitRatios.push({
                                    unit1: unit1,
                                    unit2: unit3,
                                    num1: 1,
                                    num2: ratio3
                                });
                            } else {
                                // 没有检测到递进关系，直接添加每个单位与基本单位的关系
                                orderedSubUnitData.forEach(subUnit => {
                                    const baseRatio = 1;
                                    const subRatio = parseInt(subUnit.ratio) || 1;

                                    unitRatios.push({
                                        unit1: baseUnit,
                                        unit2: subUnit.unit_name,
                                        num1: baseRatio,
                                        num2: subRatio
                                    });
                                });
                            }
                        } else {
                            // 非标准单位组合，直接添加每个单位与基本单位的关系
                            orderedSubUnitData.forEach(subUnit => {
                                const baseRatio = 1;
                                const subRatio = parseInt(subUnit.ratio) || 1;

                                unitRatios.push({
                                    unit1: baseUnit,
                                    unit2: subUnit.unit_name,
                                    num1: baseRatio,
                                    num2: subRatio
                                });
                            });
                        }
                    } else {
                        // 不是三单位组合，直接添加每个单位与基本单位的关系
                        orderedSubUnitData.forEach(subUnit => {
                            const baseRatio = 1;
                            const subRatio = parseInt(subUnit.ratio) || 1;

                            unitRatios.push({
                                unit1: baseUnit,
                                unit2: subUnit.unit_name,
                                num1: baseRatio,
                                num2: subRatio
                            });
                        });
                    }
                } else {
                    // 只有一个副单位，直接添加与基本单位的关系
                    orderedSubUnitData.forEach(subUnit => {
                        const baseRatio = 1;
                        const subRatio = parseInt(subUnit.ratio) || 1;

                        unitRatios.push({
                            unit1: baseUnit,
                            unit2: subUnit.unit_name,
                            num1: baseRatio,
                            num2: subRatio
                        });
                    });
                }

                // 更新UI
                unitDisplay.textContent = baseUnit;
                updateUnitRatiosData();
                updateUnitRatiosList();

                // 禁用输入
                unitRatioInput.disabled = true;
                unitRatioInput.style.display = "none";
                document.getElementById('clear-unit-message').style.display = 'inline-block';
            };

            window.updatePriceStrategyTable = updatePriceStrategyTable;
            updatePriceStrategyTable(unitSelect.value);

            // "请先删除现有单位配比"按钮添加点击事件
            document.getElementById('clear-unit-message').addEventListener('click', function() {
                if (unitRatios && unitRatios.length > 0) {
                    if (confirm('确定要删除所有单位配比吗？')) {
                        deleteUnitRatio(); // 调用删除函数清空所有单位配比
                    }
                }
            });
        }

        // 单位自动填充功能
        function initUnitAutoFill() {
            const unitSelect = document.querySelector('select[name="unit"]');
            const multiUnitCheckbox = document.querySelector('input[name="multi_unit"]');
            const preferredInUnitSelect = document.querySelector('select[name="preferred_in_unit"]');
            const preferredOutUnitSelect = document.querySelector('select[name="preferred_out_unit"]');

            unitSelect.addEventListener('change', function() {
                if (!multiUnitCheckbox.checked) {
                    const selectedUnit = this.value;
                    if (selectedUnit) {
                        preferredInUnitSelect.value = selectedUnit;
                        preferredOutUnitSelect.value = selectedUnit;
                    }
                }

                if (window.updatePriceStrategyTable) {
                    window.updatePriceStrategyTable(this.value);
                }
            });
        }

        // 图片处理功能
        function initImageHandlers() {
            const productImagesInput = document.getElementById('product-images');
            if (productImagesInput) {
                productImagesInput.addEventListener('change', function() {
                    const container = document.getElementById('image-preview-container');
                    // 保留已有的图片，只清除临时上传的图片
                    const existingImages = container.querySelector('.current-images');
                    container.innerHTML = '';
                    if (existingImages) {
                        container.appendChild(existingImages);
                    }
                    deletedImageIndexes = []; // 重置已删除图片索引

                    if (this.files.length > 0) {
                        const maxFiles = 20;
                        const filesToProcess = Math.min(this.files.length, maxFiles);

                        for (let i = 0; i < filesToProcess; i++) {
                            const file = this.files[i];
                            if (!file.type.match('image.*')) continue;

                            const reader = new FileReader();
                            reader.onload = (function(file, index) {
                                return function(e) {
                                    const div = document.createElement('div');
                                    div.className = 'image-item temp-image';
                                    div.dataset.index = index; // 添加索引属性

                                    const img = document.createElement('img');
                                    img.src = e.target.result;
                                    img.className = 'preview-image';
                                    img.alt = '预览图片';

                                    if (!existingImages && index === 0) {
                                        const span = document.createElement('span');
                                        span.className = 'main-label';
                                        span.textContent = '主图';
                                        div.appendChild(span);
                                    }

                                    const button = document.createElement('button');
                                    button.type = 'button';
                                    button.className = 'delete-image';
                                    button.textContent = '×';
                                    button.title = '移除图片';
                                    button.onclick = function() {
                                        div.remove();
                                    };

                                    div.appendChild(img);
                                    div.appendChild(button);
                                    container.appendChild(div);
                                };
                            })(file, i);

                            reader.readAsDataURL(file);
                        }
                    }
                });
            }

            // 删除现有图片功能
            const container = document.getElementById('image-preview-container');
            if (container) {
                container.addEventListener('click', function(e) {
                    if (e.target.classList.contains('delete-image')) {
                        const button = e.target;
                        const imageItem = button.closest('.image-item');
                        const imageId = button.dataset.imageId;

                        if (imageId) {
                            // 询问用户是否确认删除
                            if (confirm('确定要删除此图片吗？此操作无法撤销')) {
                                // 使用AJAX删除图片
                                const formData = new FormData();
                                formData.append('image_id', imageId);

                                fetch('delete_image.php', {
                                        method: 'POST',
                                        body: formData
                                    })
                                    .then(response => {
                                        if (!response.ok) {
                                            throw new Error('网络响应异常');
                                        }
                                        return response.json();
                                    })
                                    .then(data => {
                                        if (data.status === 'success') {
                                            // 删除成功，移除预览
                                            imageItem.remove();
                                            showMessage('图片已删除');
                                        } else {
                                            showMessage('删除失败：' + data.message);
                                        }
                                    })
                                    .catch(error => {
                                        console.error('删除请求出错:', error);
                                        showMessage('删除请求失败，请稍后重试');
                                    });
                            }
                        } else {
                            // 临时图片直接移除，并记录索引
                            const index = parseInt(imageItem.dataset.index);
                            if (!isNaN(index) && !deletedImageIndexes.includes(index)) {
                                deletedImageIndexes.push(index);
                            }
                            imageItem.remove();
                        }
                    }
                });
            }

            // 重置按钮处理
            const resetButton = document.querySelector('button[type="reset"]');
            if (resetButton) {
                resetButton.addEventListener('click', function() {
                    const container = document.getElementById('image-preview-container');
                    const tempImages = container.querySelectorAll('.temp-image');
                    tempImages.forEach(item => item.remove());
                });
            }
        }
    </script>
</body>

</html>