<?php
// list_products.php
// 引入数据库配置文件
require_once '../config.php';

// 数据库连接
$conn = get_db_connection();

// 搜索条件
$search = isset($_GET['search']) ? trim($_GET['search']) : '';
$whereClause = "";
if (!empty($search)) {
    $search = $conn->real_escape_string($search);
    $whereClause = "WHERE product_name LIKE '%$search%' OR product_code LIKE '%$search%' OR barcode LIKE '%$search%'";
}

// 分页
$page = isset($_GET['page']) ? intval($_GET['page']) : 1;
$limit = 10; // 每页显示10条
$offset = ($page - 1) * $limit;

// 获取总数
$countSql = "SELECT COUNT(*) as total FROM products $whereClause";
$countResult = $conn->query($countSql);
$totalRows = $countResult->fetch_assoc()['total'];
$totalPages = ceil($totalRows / $limit);

// 获取当前页数据
$redisManager = get_redis_instance();
$cacheKey = "products:list:{$page}:{$limit}:" . md5($search);

// 检查是否需要强制刷新缓存
$forceRefresh = isset($_GET['refresh']) && $_GET['refresh'] == '1';

// Redis调试信息
$redisDebug = [
    'available' => false,
    'cache_key' => $cacheKey,
    'cache_hit' => false,
    'time_saved' => 0,
    'redis_prefix' => $redis_prefix ?? '',
    'full_key' => ($redis_prefix ?? '') . $cacheKey,
    'expiry' => 300,
    'force_refresh' => $forceRefresh
];

// 添加Redis可用性检查
$products = null;
$startTime = microtime(true);
if (!$forceRefresh && $redisManager->isAvailable()) {
    $redisDebug['available'] = true;
    // 尝试从缓存获取
    $products = $redisManager->get($cacheKey);
    if ($products) {
        $redisDebug['cache_hit'] = true;
        $redisDebug['time_saved'] = microtime(true) - $startTime;
    }
}

if (!$products) {
    // 缓存未命中或需强制刷新，从数据库获取
    $dbStartTime = microtime(true);
    $sql = "
    SELECT p.id, p.product_code, p.product_name, p.unit, p.retail_price, p.vip_price, p.created_at,
           (SELECT file_path FROM product_images WHERE product_id = p.id AND is_main = 1 LIMIT 1) AS main_image
    FROM products p
    $whereClause
    ORDER BY p.id DESC
    LIMIT $offset, $limit
    ";

    $result = $conn->query($sql);
    $products = [];

    while ($row = $result->fetch_assoc()) {
        $products[] = $row;
    }

    $redisDebug['db_query_time'] = microtime(true) - $dbStartTime;

    // 只在Redis可用时缓存结果
    if ($redisManager->isAvailable()) {
        $redisDebug['cache_set'] = true;
        $redisManager->set($cacheKey, $products, 300);
    }
}

// 获取提示信息
$message = isset($_GET['message']) ? $_GET['message'] : '';
?>
<!DOCTYPE html>
<html lang="zh">

<head>
    <meta charset="UTF-8">
    <title>商品列表</title>
    <link rel="stylesheet" href="style.css">
</head>

<body>
    <div class="header">
        <h2>商品列表</h2>
        <div class="button-group">
            <a href="add_product.php" class="btn btn-add">添加商品</a>
        </div>
    </div>

    <!-- 消息显示区域 -->
    <div id="message-container"></div>

    <form action="" method="get" class="search-box">
        <input type="text" name="search" placeholder="搜索商品名称/编号/条码" value="<?= htmlspecialchars($search) ?>">
        <button type="submit">搜索</button>
    </form>

    <div class="table-container">
        <table>
            <thead>
                <tr>
                    <th width="100">主图</th>
                    <th width="120">商品编号</th>
                    <th>商品名称</th>
                    <th width="100">基本单位</th>
                    <th width="100">零售价</th>
                    <th width="100">VIP价</th>
                    <th width="150">创建时间</th>
                    <th width="100">操作</th>
                </tr>
            </thead>
            <tbody>
                <?php if (count($products) > 0): ?>
                    <?php foreach ($products as $row): ?>
                        <tr>
                            <td>
                                <?php if ($row['main_image']): ?>
                                    <?php
                                    // 处理图片路径
                                    $imgPath = $row['main_image'];
                                    // 如果路径不是以../开头，则添加../前缀
                                    if (strpos($imgPath, '../') !== 0) {
                                        $imgPath = '../' . $imgPath;
                                    }
                                    ?>
                                    <img src="<?= $imgPath ?>" class="thumb" alt="<?= htmlspecialchars($row['product_name']) ?>">
                                <?php else: ?>
                                    <div class="no-image">无图</div>
                                <?php endif; ?>
                            </td>
                            <td><?= htmlspecialchars($row['product_code']) ?></td>
                            <td><?= htmlspecialchars($row['product_name']) ?></td>
                            <td><?= htmlspecialchars($row['unit']) ?></td>
                            <td>¥<?= number_format($row['retail_price'], 2) ?></td>
                            <td>¥<?= number_format($row['vip_price'], 2) ?></td>
                            <td><?= $row['created_at'] ?></td>
                            <td><a href="edit_product.php?id=<?= $row['id'] ?>" class="btn">编辑</a></td>
                        </tr>
                    <?php endforeach; ?>
                <?php else: ?>
                    <tr>
                        <td colspan="8" style="text-align: center; padding: 30px;">暂无商品数据</td>
                    </tr>
                <?php endif; ?>
            </tbody>
        </table>
    </div>

    <!-- 分页 -->
    <?php if ($totalPages > 1): ?>
        <div class="pagination">
            <?php if ($page > 1): ?>
                <a href="?page=1<?= !empty($search) ? '&search=' . urlencode($search) : '' ?>">首页</a>
                <a href="?page=<?= $page - 1 . (!empty($search) ? '&search=' . urlencode($search) : '') ?>">上一页</a>
            <?php endif; ?>

            <?php
            // 显示页码范围
            $startPage = max(1, $page - 2);
            $endPage = min($totalPages, $page + 2);

            for ($i = $startPage; $i <= $endPage; $i++):
                if ($i == $page):
            ?>
                    <span class="current"><?= $i ?></span>
                <?php else: ?>
                    <a href="?page=<?= $i . (!empty($search) ? '&search=' . urlencode($search) : '') ?>"><?= $i ?></a>
            <?php endif;
            endfor; ?>

            <?php if ($page < $totalPages): ?>
                <a href="?page=<?= $page + 1 . (!empty($search) ? '&search=' . urlencode($search) : '') ?>">下一页</a>
                <a href="?page=<?= $totalPages . (!empty($search) ? '&search=' . urlencode($search) : '') ?>">末页</a>
            <?php endif; ?>
        </div>
    <?php endif; ?>

    <script>
        // 消息显示函数
        function showMessage(message, type = 'success') {
            const messageContainer = document.getElementById('message-container');
            messageContainer.innerHTML = `
                <div class="message">
                    <span>${message}</span>
                    <button onclick="this.parentElement.remove()">×</button>
                </div>
            `;

            // 3秒后自动消失
            setTimeout(() => {
                const messageElement = messageContainer.querySelector('.message');
                if (messageElement) {
                    messageElement.remove();
                }
            }, 3000);
        }

        // 检查URL参数是否包含消息
        const urlParams = new URLSearchParams(window.location.search);
        const message = urlParams.get('message');
        if (message) {
            showMessage(decodeURIComponent(message));
        }

        // Redis调试信息输出到控制台
        console.log('========== Redis缓存调试信息 ==========');
        console.log('Redis可用: <?= $redisDebug['available'] ? '是' : '否' ?>');
        console.log('缓存键名: <?= $redisDebug['cache_key'] ?>');
        console.log('带前缀的完整键名: <?= $redisDebug['full_key'] ?>');
        console.log('缓存命中: <?= $redisDebug['cache_hit'] ? '是' : '否' ?>');
        <?php if ($redisDebug['cache_hit']): ?>
            console.log('节省查询时间: <?= number_format($redisDebug['time_saved'] * 1000, 2) ?> 毫秒');
        <?php else: ?>
            console.log('数据库查询时间: <?= isset($redisDebug['db_query_time']) ? number_format($redisDebug['db_query_time'] * 1000, 2) : 0 ?> 毫秒');
            console.log('缓存结果: <?= isset($redisDebug['cache_set']) && $redisDebug['cache_set'] ? '是' : '否' ?>');
        <?php endif; ?>
        console.log('缓存过期时间: <?= $redisDebug['expiry'] ?> 秒');
        console.log('========================================');
    </script>
</body>

</html>