<?php
// 引入数据库配置文件
require_once '../config.php';

// 数据库连接
$conn = get_db_connection();

// 字段与数据类型（i=int, d=decimal, s=string）
$fields = [
    'product_code' => 's',
    'product_name' => 's',
    'barcode' => 's',
    'category_id' => 'i',
    'warehouse_id' => 'i',
    'specification' => 's',
    'unit' => 's',
    'multi_unit' => 'i',
    'preferred_in_unit' => 's',
    'preferred_out_unit' => 's',
    'origin' => 's',
    'registration_number' => 's',
    'brand' => 's',
    'plu_code' => 'i',
    'supplier_id' => 'i',
    'weight' => 'd',
    'length' => 'd',
    'width' => 'd',
    'height' => 'd',
    'price_strategy_enabled' => 'i',
    'retail_price' => 'd',
    'wholesale_price' => 'd',
    'vip_price' => 'd',
    'discount1' => 'd',
    'discount2' => 'd',
    'min_sale_price' => 'd',
    'estimated_purchase_price' => 'd',
    'max_purchase_price' => 'd',
    'tax_rate' => 'd',
    'tax_code' => 's',
    'is_tax_exempt' => 'i',
    'invoice_name' => 's',
    'remarks' => 's'
];

$data = [];
$types = ''; // 用于 bind_param

foreach ($fields as $field => $type) {
    if ($type == 'i') {
        $value = isset($_POST[$field]) && $_POST[$field] !== '' ? (int)$_POST[$field] : null;
    } elseif ($type == 'd') {
        $value = isset($_POST[$field]) && $_POST[$field] !== '' ? (float)$_POST[$field] : null;
    } else {
        $value = isset($_POST[$field]) ? trim($_POST[$field]) : null;
    }

    // 特殊处理 checkbox
    if (in_array($field, ['multi_unit', 'price_strategy_enabled'])) {
        $value = isset($_POST[$field]) ? 1 : 0;
    }

    $data[] = $value;
    $types .= $type;
}

// 构造 SQL
$sql = "INSERT INTO products (" . implode(",", array_keys($fields)) . ")
        VALUES (" . rtrim(str_repeat("?,", count($fields)), ",") . ")";

$stmt = $conn->prepare($sql);

// 动态绑定参数
$stmt->bind_param($types, ...$data);

/**
 * 上传商品图片
 */
function upload_product_images($product_id, $conn)
{
    $upload_dir = __DIR__ . '/../uploads/products/';
    if (!file_exists($upload_dir)) {
        mkdir($upload_dir, 0777, true);
    }

    $files = $_FILES['product_images'];
    $count = count($files['name']);
    $uploaded = 0;

    // 处理已删除的图片索引
    $deletedIndexes = [];
    if (isset($_POST['deleted_image_indexes']) && !empty($_POST['deleted_image_indexes'])) {
        $deletedIndexes = json_decode($_POST['deleted_image_indexes'], true);
        if (!is_array($deletedIndexes)) {
            $deletedIndexes = [];
        }
    }

    for ($i = 0; $i < $count; $i++) {
        // 跳过已删除的图片
        if (in_array($i, $deletedIndexes)) {
            continue;
        }

        if (!is_uploaded_file($files['tmp_name'][$i])) continue;

        $ext = pathinfo($files['name'][$i], PATHINFO_EXTENSION);
        if (!in_array(strtolower($ext), ['jpg', 'jpeg', 'png'])) continue;

        $newName = time() . '_' . mt_rand(1000, 9999) . '.' . $ext;
        $target = $upload_dir . $newName;
        if (move_uploaded_file($files['tmp_name'][$i], $target)) {
            $file_path = '../uploads/products/' . $newName;
            $is_main = ($uploaded === 0) ? 1 : 0; // 第一张图作为主图
            $stmt = $conn->prepare("INSERT INTO product_images (product_id, file_path, is_main) VALUES (?, ?, ?)");
            $stmt->bind_param("isi", $product_id, $file_path, $is_main);
            $stmt->execute();
            $uploaded++;
        }

        if ($uploaded >= 20) break;
    }
}

if ($stmt->execute()) {
    $product_id = $conn->insert_id;

    // 处理多单位数据
    if (isset($_POST['unit_ratios']) && !empty($_POST['unit_ratios'])) {
        $unitRatios = json_decode($_POST['unit_ratios'], true);
        if (is_array($unitRatios) && count($unitRatios) > 0) {
            // 先删除现有的单位数据
            $conn->query("DELETE FROM product_units WHERE product_id = $product_id");

            // 添加基本单位
            $baseUnit = $unitRatios[0]['baseUnit'];
            $stmtBaseUnit = $conn->prepare("INSERT INTO product_units (product_id, unit_type, unit_name, ratio) VALUES (?, 'base', ?, 1)");
            $stmtBaseUnit->bind_param("is", $product_id, $baseUnit);
            $stmtBaseUnit->execute();

            // 添加副单位
            $stmtSubUnit = $conn->prepare("INSERT INTO product_units (product_id, unit_type, unit_name, ratio) VALUES (?, 'sub', ?, ?)");
            foreach ($unitRatios as $ratio) {
                $subUnit = $ratio['subUnit'];
                $ratioValue = floatval($ratio['ratio2']) / floatval($ratio['ratio1']);
                $stmtSubUnit->bind_param("isd", $product_id, $subUnit, $ratioValue);
                $stmtSubUnit->execute();
            }
        }
    }

    // 上传商品图片
    if (!empty($_FILES['product_images']['name'][0])) {
        upload_product_images($product_id, $conn);
    }

    // 清除Redis缓存
    $redisManager = get_redis_instance();
    if ($redisManager->isAvailable()) {
        // 删除所有商品列表相关的缓存
        $redis = $redisManager->getRedis();
        $pattern = "products:list:*";
        $keys = $redis->keys($pattern);
        if (is_array($keys) && count($keys) > 0) {
            foreach ($keys as $key) {
                $redis->del($key);
            }
        }
    }

    // 检查是否是批量添加模式
    $batchAdd = isset($_POST['batch_add']) && $_POST['batch_add'] == 1;

    echo "✅ 商品保存成功！";
} else {
    echo "❌ 错误: " . $stmt->error;
}

$stmt->close();
$conn->close();
